```@meta
EditURL = "../../../examples/working_with_ollama.jl"
```

# Local models with Ollama.ai

This file contains examples of how to work with [Ollama.ai](https://ollama.ai/) models.
It assumes that you've already installated and launched the Ollama server. For more details or troubleshooting advice, see the [Frequently Asked Questions](@ref) section.

First, let's import the package and define a helper link for calling un-exported functions:

````julia
using PromptingTools
const PT = PromptingTools
````

````
PromptingTools
````

Notice the schema change! If you want this to be the new default, you need to change `PT.PROMPT_SCHEMA`

````julia
schema = PT.OllamaManagedSchema()
````

````
OllamaManagedSchema()
````

You can choose models from https://ollama.ai/library - I prefer `openhermes2.5-mistral`

````julia
model = "openhermes2.5-mistral"
````

````
"openhermes2.5-mistral"
````

## Text Generation with aigenerate

### Simple message

````julia
msg = aigenerate(schema, "Say hi!"; model)
````

````
AIMessage("Hi there! How can I help you today? If you have any questions or need assistance, please feel free to ask.")
````

### Standard string interpolation

````julia
a = 1
msg = aigenerate(schema, "What is `$a+$a`?"; model)

name = "John"
msg = aigenerate(schema, "Say hi to {{name}}."; name, model)
````

````
AIMessage("Hi there, John! It's great to see you today. How can I assist you? If you have any questions or need help with something, please don't hesitate to ask!")
````

### Advanced Prompts

````julia
conversation = [
    PT.SystemMessage("You're master Yoda from Star Wars trying to help the user become a Yedi."),
    PT.UserMessage("I have feelings for my iPhone. What should I do?")]
msg = aigenerate(schema, conversation; model)
````

````
AIMessage("Strong your feelings are, but attachments lead to suffering they often do. Focus on the balance in all things and let go of possessions that cloud your judgment. Embrace the wisdom of the Force and understand that material objects are not the same as love. The Force will guide you.")
````

## Embeddings with aiembed

### Simple embedding for one document

````julia
msg = aiembed(schema, "Embed me"; model) # access msg.content
````

````
DataMessage(JSON3.Array{Float64, Vector{UInt8}, SubArray{UInt64, 1, Vector{UInt64}, Tuple{UnitRange{Int64}}, true}} of size (4096,))
````

One document and we materialize the data into a Vector with copy (`postprocess` function argument)

````julia
msg = aiembed(schema, "Embed me", copy; model)
````

````
DataMessage(Vector{Float64} of size (4096,))
````

### Multiple documents embedding
Multiple documents - embedded sequentially, you can get faster speed with async

````julia
msg = aiembed(schema, ["Embed me", "Embed me"]; model)
````

````
DataMessage(Matrix{Float64} of size (4096, 2))
````

You can use Threads.@spawn or asyncmap, whichever you prefer, to paralellize the model calls

````julia
docs = ["Embed me", "Embed me"]
tasks = asyncmap(docs) do doc
    msg = aiembed(schema, doc; model)
end
embedding = mapreduce(x -> x.content, hcat, tasks)
````

````
4096×2 Matrix{Float64}:
   7.71459        7.71459
  -1.14532       -1.14532
   2.90205        2.90205
  -4.01967       -4.01967
  -7.73098       -7.73098
   8.02114        8.02114
  -6.01313       -6.01313
  -2.06712       -2.06712
   4.97633        4.97633
  -9.69502       -9.69502
  -0.02567       -0.02567
   8.09622        8.09622
   6.54008        6.54008
  -5.70348       -5.70348
   2.55213        2.55213
  -2.00164       -2.00164
  -2.21854       -2.21854
  -3.6568        -3.6568
   3.97905        3.97905
  -1.79931       -1.79931
   0.0769786      0.0769786
 -10.4355       -10.4355
  -3.92487       -3.92487
  -6.03455       -6.03455
  -2.8005        -2.8005
   2.23584        2.23584
  -0.503125      -0.503125
   1.99538        1.99538
  -0.283642      -0.283642
  -0.414273      -0.414273
   8.72909        8.72909
   2.6071         2.6071
   0.0808531      0.0808531
  -1.83914       -1.83914
   2.19998        2.19998
  -0.629226      -0.629226
   3.74217        3.74217
   1.71231        1.71231
  -0.742473      -0.742473
   2.9234         2.9234
   7.33933        7.33933
   4.24576        4.24576
  -7.56434       -7.56434
  -1.22274       -1.22274
   1.73444        1.73444
  -0.736801      -0.736801
   1.30149        1.30149
  -6.91642       -6.91642
  -1.84513       -1.84513
   1.69959        1.69959
   5.74253        5.74253
   1.48734        1.48734
  -1.45199       -1.45199
 -18.5026       -18.5026
  -8.61009       -8.61009
  -2.21845       -2.21845
  -4.22932       -4.22932
   6.0436         6.0436
  -1.8824        -1.8824
  -0.689965      -0.689965
   0.845927       0.845927
  -1.99517       -1.99517
   9.32292        9.32292
   6.24938        6.24938
  -4.59894       -4.59894
   6.24579        6.24579
  -5.8733        -5.8733
  -4.60285       -4.60285
  -1.27596       -1.27596
  -1.68807       -1.68807
  -0.391147      -0.391147
  -2.68362       -2.68362
   1.99197        1.99197
   0.0812396      0.0812396
  -3.79761       -3.79761
  -8.5693        -8.5693
  -0.869305      -0.869305
  -0.77582       -0.77582
  -4.76995       -4.76995
   1.9712         1.9712
   4.74459        4.74459
  -4.31244       -4.31244
   3.94876        3.94876
 -11.0882       -11.0882
   9.38629        9.38629
  10.2995        10.2995
   2.40846        2.40846
  -3.91429       -3.91429
  -0.745707      -0.745707
   4.31946        4.31946
   8.34836        8.34836
   0.857636       0.857636
   1.66563        1.66563
 -11.1522       -11.1522
  -3.48353       -3.48353
  -6.08336       -6.08336
   1.22086        1.22086
  -2.81636       -2.81636
   1.07224        1.07224
  -8.24909       -8.24909
   3.66474        3.66474
  -0.260558      -0.260558
   2.38779        2.38779
  -4.00576       -4.00576
   1.3949         1.3949
  -5.43468       -5.43468
   4.08836        4.08836
  -1.1134        -1.1134
  -2.05916       -2.05916
  -9.78987       -9.78987
  -2.86149       -2.86149
   5.54577        5.54577
  -1.96682       -1.96682
   9.70577        9.70577
  -4.0553        -4.0553
   8.54535        8.54535
   0.539438       0.539438
   4.61091        4.61091
  -5.32208       -5.32208
  -0.256733      -0.256733
   4.74966        4.74966
  -2.46464       -2.46464
  -0.223077      -0.223077
   1.84442        1.84442
   6.42329        6.42329
   0.431667       0.431667
  -8.42777       -8.42777
 -10.691        -10.691
   3.023          3.023
  -5.65345       -5.65345
  -4.17833       -4.17833
   0.937893       0.937893
  -6.99405       -6.99405
  -4.55107       -4.55107
 -15.3169       -15.3169
  -2.08895       -2.08895
   7.17826        7.17826
  -4.26108       -4.26108
  -3.2712        -3.2712
  16.1561        16.1561
  13.5164        13.5164
  -5.91778       -5.91778
   6.3401         6.3401
  12.7018        12.7018
   2.04305        2.04305
   3.81683        3.81683
  -1.39969       -1.39969
  -0.17249       -0.17249
 -16.3687       -16.3687
   4.3827         4.3827
   2.58974        2.58974
  -4.75363       -4.75363
   3.36371        3.36371
   0.986534       0.986534
 -13.4299       -13.4299
 -12.7188       -12.7188
   2.83107        2.83107
  -3.41115       -3.41115
  -3.01015       -3.01015
   6.40446        6.40446
  -0.186923      -0.186923
  -1.42502       -1.42502
   2.85606        2.85606
  -0.579786      -0.579786
  -3.92704       -3.92704
   8.28959        8.28959
   5.42878        5.42878
   5.71589        5.71589
  -6.78065       -6.78065
  -0.403687      -0.403687
  -1.20623       -1.20623
   4.92372        4.92372
  -1.69266       -1.69266
  -0.103872      -0.103872
   1.9163         1.9163
  -2.26831       -2.26831
  -7.64622       -7.64622
   1.02228        1.02228
   2.91952        2.91952
  -0.524167      -0.524167
  12.4803        12.4803
   7.36984        7.36984
  -7.46027       -7.46027
  -2.78773       -2.78773
   2.68293        2.68293
  -0.320891      -0.320891
   7.12037        7.12037
   3.02726        3.02726
  -2.68363       -2.68363
   4.78372        4.78372
   3.68899        3.68899
   2.08839        2.08839
   3.1873         3.1873
  -6.10744       -6.10744
  10.5419        10.5419
   6.29439        6.29439
  -9.41221       -9.41221
  -2.50548       -2.50548
  -1.14          -1.14
  -3.0203        -3.0203
  -1.73182       -1.73182
  -0.97194       -0.97194
  -6.69084       -6.69084
  -1.08986       -1.08986
  -3.83631       -3.83631
   2.2775         2.2775
  -6.91276       -6.91276
   2.4557         2.4557
  -0.477723      -0.477723
  -4.10405       -4.10405
  -3.91437       -3.91437
  -7.79672       -7.79672
  -6.19691       -6.19691
   0.356732       0.356732
   0.609725       0.609725
  -3.08225       -3.08225
   6.39968        6.39968
   1.30207        1.30207
   7.36038        7.36038
  -7.7581        -7.7581
  -6.303         -6.303
   0.348147       0.348147
  -8.38124       -8.38124
   8.68524        8.68524
  -0.873688      -0.873688
   1.19612        1.19612
   0.725645       0.725645
  -6.59284       -6.59284
  -6.59079       -6.59079
   1.03175        1.03175
  -0.236469      -0.236469
   5.01671        5.01671
   0.752329       0.752329
   5.39971        5.39971
   0.826802       0.826802
   9.38285        9.38285
   5.85717        5.85717
   1.71145        1.71145
  -1.36528       -1.36528
  -5.09575       -5.09575
   7.23996        7.23996
  12.7272        12.7272
   2.86673        2.86673
   2.86546        2.86546
   1.2423         1.2423
   6.05857        6.05857
   9.40879        9.40879
   1.47573        1.47573
   8.19025        8.19025
  12.5009        12.5009
  -4.57244       -4.57244
  -0.674127      -0.674127
   0.416418       0.416418
  -5.23336       -5.23336
  -0.771443      -0.771443
   4.72784        4.72784
  -4.9684        -4.9684
   4.75989        4.75989
   1.68141        1.68141
  -3.2264        -3.2264
   2.67195        2.67195
   0.424227       0.424227
   3.5195         3.5195
   2.22441        2.22441
  -2.4856        -2.4856
   8.03468        8.03468
   8.54339        8.54339
   3.83506        3.83506
  13.5693        13.5693
   2.44909        2.44909
   2.70572        2.70572
   6.13746        6.13746
   1.26651        1.26651
   8.25694        8.25694
  -3.59258       -3.59258
   3.77765        3.77765
  -0.144755      -0.144755
   3.15706        3.15706
  -2.3952        -2.3952
   9.82079        9.82079
   8.94186        8.94186
  -1.83071       -1.83071
   1.45764        1.45764
 -11.8258       -11.8258
  -0.737553      -0.737553
  -1.2382        -1.2382
   1.83341        1.83341
  -2.75977       -2.75977
   3.75117        3.75117
   6.04452        6.04452
  -4.40271       -4.40271
  -8.82336       -8.82336
  10.8513        10.8513
  -4.91857       -4.91857
  -5.7401        -5.7401
   7.22234        7.22234
   7.15112        7.15112
   1.81187        1.81187
   8.19917        8.19917
   2.91605        2.91605
   3.82883        3.82883
  -0.208109      -0.208109
   1.33796        1.33796
   5.69606        5.69606
  -2.19266       -2.19266
  -5.91177       -5.91177
   7.25269        7.25269
  -8.65987       -8.65987
  -3.47799       -3.47799
 -10.4904       -10.4904
  -0.00963959    -0.00963959
  -6.81662       -6.81662
  -2.05566       -2.05566
   2.10144        2.10144
   2.58138        2.58138
   2.03289        2.03289
  -6.43532       -6.43532
  -2.97225       -2.97225
  -4.71142       -4.71142
   4.97199        4.97199
   3.687          3.687
   1.8587         1.8587
  -0.444899      -0.444899
  -1.05556       -1.05556
   4.15926        4.15926
   5.48777        5.48777
   2.28346        2.28346
  -4.69401       -4.69401
   1.8873         1.8873
  -2.62671       -2.62671
   1.4144         1.4144
  -2.97535       -2.97535
   0.759131       0.759131
   5.75781        5.75781
  -5.13309       -5.13309
   1.72701        1.72701
   2.96653        2.96653
 -10.8087       -10.8087
   1.07262        1.07262
  -5.80018       -5.80018
   1.90592        1.90592
  -5.42958       -5.42958
   8.74889        8.74889
  -3.19785       -3.19785
  -2.7096        -2.7096
   7.44399        7.44399
  -8.7433        -8.7433
  11.6667        11.6667
   2.59703        2.59703
   4.22273        4.22273
  -4.68793       -4.68793
  -4.44601       -4.44601
  -0.57319       -0.57319
   6.63389        6.63389
  -9.14857       -9.14857
  -1.34147       -1.34147
   7.78513        7.78513
  -4.87331       -4.87331
  -5.06022       -5.06022
   3.13076        3.13076
  -3.49373       -3.49373
   3.12637        3.12637
   0.566696       0.566696
   4.99319        4.99319
   3.57986        3.57986
   0.607679       0.607679
   2.37633        2.37633
   0.35097        0.35097
   0.239089       0.239089
  -6.51449       -6.51449
  -3.18838       -3.18838
   0.770256       0.770256
   2.09481        2.09481
   5.36062        5.36062
  -5.25216       -5.25216
  -6.9523        -6.9523
   3.97384        3.97384
   8.7784         8.7784
  -3.91837       -3.91837
  -9.08965       -9.08965
  -1.17883       -1.17883
  -4.21353       -4.21353
  -5.0915        -5.0915
   3.74499        3.74499
  -4.39715       -4.39715
   2.13732        2.13732
   5.97568        5.97568
   1.11809        1.11809
  -3.93191       -3.93191
  -1.39764       -1.39764
  -4.23595       -4.23595
   0.103914       0.103914
  -2.34387       -2.34387
  -4.95433       -4.95433
   3.58645        3.58645
   0.818317       0.818317
   6.23266        6.23266
  -5.62973       -5.62973
  -7.45604       -7.45604
   1.29222        1.29222
   0.327714       0.327714
   5.31996        5.31996
  -2.23663       -2.23663
   0.058689       0.058689
  -0.74368       -0.74368
  -1.20749       -1.20749
  -4.75414       -4.75414
   2.10011        2.10011
  -6.86479       -6.86479
   1.58403        1.58403
   0.0492497      0.0492497
   0.32083        0.32083
  -3.11682       -3.11682
   4.61797        4.61797
  -0.399561      -0.399561
  -7.89927       -7.89927
  -0.659676      -0.659676
  -2.2416        -2.2416
   0.933026       0.933026
   1.98848        1.98848
  -2.14547       -2.14547
  -1.10747       -1.10747
   8.90983        8.90983
  -3.84128       -3.84128
   9.82771        9.82771
   3.02843        3.02843
   3.26396        3.26396
   6.75629        6.75629
   0.0290972      0.0290972
   7.92768        7.92768
   7.44608        7.44608
  -4.14083       -4.14083
  -1.39636       -1.39636
   2.87656        2.87656
   3.87446        3.87446
   0.112521       0.112521
  -3.3429        -3.3429
  -6.85823       -6.85823
   1.18408        1.18408
   3.53175        3.53175
   3.56147        3.56147
   5.41961        5.41961
  -1.5263        -1.5263
   3.05559        3.05559
  -5.7201        -5.7201
  -3.98882       -3.98882
  -0.131939      -0.131939
   6.25683        6.25683
   0.712945       0.712945
   4.17266        4.17266
   9.04425        9.04425
  -2.39179       -2.39179
   3.03807        3.03807
   5.79693        5.79693
  -5.28875       -5.28875
  -2.56482       -2.56482
  -1.00679       -1.00679
  -0.512488      -0.512488
  -4.60373       -4.60373
  -2.69188       -2.69188
   0.958182       0.958182
  -1.08075       -1.08075
   2.66033        2.66033
  -5.77563       -5.77563
   5.393          5.393
   0.822122       0.822122
   3.50281        3.50281
  -1.90373       -1.90373
  -3.41986       -3.41986
  -7.32502       -7.32502
  -2.0256        -2.0256
  -6.28488       -6.28488
   0.358393       0.358393
   1.89312        1.89312
  -0.709162      -0.709162
  -4.43491       -4.43491
  -3.56097       -3.56097
  -8.3806        -8.3806
  -5.56256       -5.56256
  -3.40994       -3.40994
  -6.15002       -6.15002
   0.949459       0.949459
   3.18256        3.18256
   6.31834        6.31834
  12.4998        12.4998
  -6.16927       -6.16927
  -1.73781       -1.73781
   0.274813       0.274813
   7.11001        7.11001
   6.79962        6.79962
   2.00121        2.00121
  -4.30592       -4.30592
  -2.38345       -2.38345
   7.50502        7.50502
  -3.56375       -3.56375
  -1.07828       -1.07828
   7.4632         7.4632
  -5.78317       -5.78317
  -0.54432       -0.54432
   8.82699        8.82699
  -2.51939       -2.51939
  -3.21417       -3.21417
   3.06052        3.06052
  -0.45856       -0.45856
   8.89456        8.89456
   5.89006        5.89006
   1.01204        1.01204
   4.9875         4.9875
  -1.63          -1.63
   1.35424        1.35424
   3.72608        3.72608
  -8.53795       -8.53795
  -5.93051       -5.93051
  -2.35685       -2.35685
   3.51823        3.51823
   3.65767        3.65767
  -3.04233       -3.04233
  -1.12453       -1.12453
  -1.68299       -1.68299
  -5.69175       -5.69175
   3.66601        3.66601
  -3.11779       -3.11779
  -0.20161       -0.20161
   0.78317        0.78317
   2.28035        2.28035
  -4.43493       -4.43493
   2.12557        2.12557
   6.97219        6.97219
   4.91357        4.91357
  -1.87778       -1.87778
   1.98163        1.98163
   1.01184        1.01184
   0.0544142      0.0544142
  -0.748318      -0.748318
  10.0677        10.0677
  -5.50226       -5.50226
   3.89987        3.89987
   1.38136        1.38136
   4.67073        4.67073
   5.3372         5.3372
  -1.29886       -1.29886
  -0.965173      -0.965173
   0.546909       0.546909
   5.87692        5.87692
 -10.1356       -10.1356
   0.541422       0.541422
   0.486656       0.486656
   8.42395        8.42395
  -4.04554       -4.04554
  11.4728        11.4728
  -6.54655       -6.54655
   6.90602        6.90602
 -13.8383       -13.8383
   2.64142        2.64142
   3.96547        3.96547
  -0.887154      -0.887154
   0.0442338      0.0442338
  -5.12331       -5.12331
   4.95632        4.95632
   3.15264        3.15264
   4.80494        4.80494
  -5.42313       -5.42313
  -4.2795        -4.2795
   1.661          1.661
   3.85204        3.85204
  10.1308        10.1308
  -4.34526       -4.34526
  -5.49571       -5.49571
   3.92939        3.92939
  -3.28527       -3.28527
   0.154911       0.154911
  -3.606         -3.606
   5.91814        5.91814
  -8.85249       -8.85249
   9.38796        9.38796
  -0.800741      -0.800741
  -2.87508       -2.87508
   2.99955        2.99955
  -7.13252       -7.13252
  -6.77081       -6.77081
  -2.28359       -2.28359
  -0.180517      -0.180517
   7.04622        7.04622
   4.2577         4.2577
  -4.73655       -4.73655
  -0.249759      -0.249759
   2.4412         2.4412
   8.47175        8.47175
  -3.24927       -3.24927
 -12.5242       -12.5242
  -2.74845       -2.74845
  -9.32786       -9.32786
   4.21624        4.21624
   2.94687        2.94687
   3.35216        3.35216
  -3.5485        -3.5485
   6.97298        6.97298
   2.01617        2.01617
   4.70745        4.70745
   2.96924        2.96924
  -0.18365       -0.18365
  -0.694247      -0.694247
  -7.14459       -7.14459
   5.38548        5.38548
   2.04923        2.04923
  -5.33216       -5.33216
   5.47927        5.47927
   0.357422       0.357422
   4.36552        4.36552
   6.88375        6.88375
  -6.47244       -6.47244
  -3.40726       -3.40726
  -6.56449       -6.56449
   6.34818        6.34818
  -4.23984       -4.23984
 -11.1113       -11.1113
   2.41915        2.41915
   3.90153        3.90153
  -7.69422       -7.69422
  -8.03709       -8.03709
  -9.64719       -9.64719
  -4.04416       -4.04416
   2.64435        2.64435
   5.11566        5.11566
  -1.27873       -1.27873
  -1.01265       -1.01265
  -8.38716       -8.38716
  -0.960571      -0.960571
   2.05458        2.05458
  -1.89606       -1.89606
  -7.04401       -7.04401
   4.91798        4.91798
   2.12484        2.12484
   2.38768        2.38768
   7.9691         7.9691
  -1.00886       -1.00886
  -4.9569        -4.9569
  -4.74278       -4.74278
   0.191814       0.191814
  -5.2925        -5.2925
  -1.15484       -1.15484
   2.27898        2.27898
   4.12308        4.12308
  -6.18988       -6.18988
   7.1232         7.1232
  -6.68678       -6.68678
   1.65808        1.65808
   8.53283        8.53283
   0.509069       0.509069
  -3.03638       -3.03638
  -4.86641       -4.86641
   7.20729        7.20729
  -7.51236       -7.51236
   3.37738        3.37738
  -0.0649395     -0.0649395
   2.75749        2.75749
  -5.61535       -5.61535
   3.1237         3.1237
  -0.766488      -0.766488
   4.39047        4.39047
   1.28616        1.28616
  -8.02003       -8.02003
   4.21688        4.21688
  -2.79942       -2.79942
  -5.80171       -5.80171
   9.97235        9.97235
  21.8011        21.8011
  -3.58992       -3.58992
   5.03481        5.03481
  -2.1684        -2.1684
  -5.46844       -5.46844
   1.57702        1.57702
  -4.53923       -4.53923
  -1.77363       -1.77363
  -0.489051      -0.489051
  -0.371992      -0.371992
   8.264          8.264
   1.63502        1.63502
  -1.10134       -1.10134
   4.76612        4.76612
   5.93085        5.93085
  -2.07348       -2.07348
   4.26074        4.26074
   4.1331         4.1331
  11.1442        11.1442
   2.18824        2.18824
   2.18854        2.18854
   0.210843       0.210843
  -9.30743       -9.30743
   5.34539        5.34539
  -4.21419       -4.21419
  -3.97284       -3.97284
  -2.67745       -2.67745
   4.17366        4.17366
   2.41498        2.41498
   0.801359       0.801359
   8.35766        8.35766
  -1.29589       -1.29589
  -7.45531       -7.45531
  -7.26731       -7.26731
   4.06669        4.06669
  -2.35771       -2.35771
  -8.73174       -8.73174
  -0.837329      -0.837329
  -2.53419       -2.53419
  44.3977        44.3977
  13.5049        13.5049
  -3.66878       -3.66878
  -6.5533        -6.5533
  -5.59814       -5.59814
 -10.5759       -10.5759
   0.663108       0.663108
  -3.45147       -3.45147
  -3.75944       -3.75944
   1.84721        1.84721
  -0.363204      -0.363204
   4.54678        4.54678
   2.07408        2.07408
   7.85227        7.85227
  -7.53707       -7.53707
   4.18344        4.18344
  -1.96048       -1.96048
   6.24217        6.24217
  -9.16295       -9.16295
   0.0480544      0.0480544
   2.84725        2.84725
   1.08008        1.08008
  -0.874464      -0.874464
   1.67428        1.67428
  -1.91245       -1.91245
   3.53596        3.53596
   3.75983        3.75983
   1.37903        1.37903
  -0.799744      -0.799744
   2.75015        2.75015
 -11.0835       -11.0835
  -1.6781        -1.6781
   2.86463        2.86463
 -11.1467       -11.1467
  -3.76398       -3.76398
   9.06439        9.06439
   9.84403        9.84403
  -5.07          -5.07
   3.2952         3.2952
  -1.62527       -1.62527
  -7.98997       -7.98997
  -7.8193        -7.8193
   1.10895        1.10895
   0.460921       0.460921
  -1.47816       -1.47816
   0.718936       0.718936
  -3.74006       -3.74006
  -2.87535       -2.87535
   0.037427       0.037427
  -4.49959       -4.49959
   0.0987492      0.0987492
   1.8443         1.8443
   0.748879       0.748879
   1.4364         1.4364
  -0.90809       -0.90809
  -1.36403       -1.36403
  -1.27123       -1.27123
   3.09447        3.09447
  -3.82708       -3.82708
   0.683696       0.683696
   3.96997        3.96997
   0.461267       0.461267
   4.96801        4.96801
  -5.96169       -5.96169
   2.56714        2.56714
 -10.7519       -10.7519
  -3.39381       -3.39381
   1.15623        1.15623
  -3.95798       -3.95798
  -1.42797       -1.42797
   4.85734        4.85734
  -4.46424       -4.46424
 -11.9172       -11.9172
   0.740766       0.740766
  -2.06857       -2.06857
  -1.23723       -1.23723
  -6.43373       -6.43373
   7.04893        7.04893
  -1.10208       -1.10208
  -0.0507102     -0.0507102
   8.23443        8.23443
  -1.71378       -1.71378
   2.769          2.769
   9.77752        9.77752
   0.423859       0.423859
   0.901832       0.901832
   0.0738559      0.0738559
  -0.487266      -0.487266
   2.05358        2.05358
  -8.73912       -8.73912
   3.01532        3.01532
  -0.926127      -0.926127
 -11.2315       -11.2315
   1.79698        1.79698
 -13.074        -13.074
   3.72342        3.72342
  -9.17341       -9.17341
   7.23722        7.23722
   3.85919        3.85919
  -4.10267       -4.10267
   5.89157        5.89157
  -1.06631       -1.06631
  -2.18366       -2.18366
  -0.0316413     -0.0316413
  -8.63864       -8.63864
  -0.194451      -0.194451
   2.71759        2.71759
  -5.19424       -5.19424
 -16.7634       -16.7634
   5.97943        5.97943
   0.319596       0.319596
 -10.0687       -10.0687
   1.12736        1.12736
   2.11687        2.11687
   2.5643         2.5643
   0.502174       0.502174
  -5.75011       -5.75011
 -11.1808       -11.1808
  -3.42246       -3.42246
   7.55982        7.55982
  -5.85592       -5.85592
   1.22363        1.22363
   1.39871        1.39871
   3.35581        3.35581
   2.99389        2.99389
  -0.762194      -0.762194
   1.39891        1.39891
  -4.24295       -4.24295
  -6.95612       -6.95612
   7.00699        7.00699
 -30.893        -30.893
  -7.3071        -7.3071
  17.5017        17.5017
  -3.26283       -3.26283
  -4.13569       -4.13569
   4.33006        4.33006
  -5.94055       -5.94055
  -0.564017      -0.564017
   5.60949        5.60949
   7.50747        7.50747
  -4.08147       -4.08147
   4.08671        4.08671
   6.72008        6.72008
  -5.02883       -5.02883
  -3.48779       -3.48779
   4.76881        4.76881
   4.5818         4.5818
  -3.10608       -3.10608
  -5.08198       -5.08198
  -5.54477       -5.54477
 -13.1989       -13.1989
  -8.63604       -8.63604
  -0.688683      -0.688683
  -2.34276       -2.34276
  -3.19008       -3.19008
   0.204818       0.204818
   0.639057       0.639057
  12.6767        12.6767
  -3.40057       -3.40057
  -6.36799       -6.36799
   3.7564         3.7564
  -3.04825       -3.04825
  -3.98011       -3.98011
  -2.21944       -2.21944
   8.40757        8.40757
  -5.6418        -5.6418
   3.3001         3.3001
  -0.678107      -0.678107
  -2.42254       -2.42254
   0.439524       0.439524
  -0.417505      -0.417505
  -4.98938       -4.98938
  -6.34015       -6.34015
  -4.84203       -4.84203
   2.86778        2.86778
   3.29409        3.29409
   2.59772        2.59772
   5.20187        5.20187
   3.55625        3.55625
  -7.065         -7.065
  -6.60792       -6.60792
  -3.20259       -3.20259
   0.417062       0.417062
  -2.39846       -2.39846
  -5.762         -5.762
   1.74843        1.74843
   8.19239        8.19239
  -1.7349        -1.7349
  -0.0331415     -0.0331415
   5.00712        5.00712
  10.611         10.611
   9.28817        9.28817
  -3.85324       -3.85324
   2.29622        2.29622
  10.962         10.962
   4.44034        4.44034
  -3.2265        -3.2265
   1.39326        1.39326
  -1.56539       -1.56539
  -8.78843       -8.78843
  -1.74101       -1.74101
   8.51953        8.51953
   3.31178        3.31178
  -1.20051       -1.20051
  -3.93224       -3.93224
   2.4431         2.4431
   3.69278        3.69278
 -10.2714       -10.2714
 -13.7579       -13.7579
  -1.76844       -1.76844
  -0.448193      -0.448193
   1.48574        1.48574
  -0.831377      -0.831377
   6.42657        6.42657
   6.51848        6.51848
   2.7764         2.7764
   4.29448        4.29448
  -1.27173       -1.27173
  -7.14856       -7.14856
   2.95751        2.95751
   2.39789        2.39789
   4.79429        4.79429
   7.29216        7.29216
  -4.91502       -4.91502
   2.38701        2.38701
  -2.34997       -2.34997
  -0.876115      -0.876115
  -0.672649      -0.672649
   4.43884        4.43884
   0.254258       0.254258
  -3.56471       -3.56471
   0.161779       0.161779
 -10.1128       -10.1128
   9.97279        9.97279
  -5.01498       -5.01498
   1.10415        1.10415
   1.37993        1.37993
  -3.32619       -3.32619
   2.57257        2.57257
  -0.137478      -0.137478
   1.49426        1.49426
  -0.805644      -0.805644
   3.25356        3.25356
   2.46332        2.46332
   1.39266        1.39266
   4.15167        4.15167
  -9.27164       -9.27164
  -2.29794       -2.29794
   0.067971       0.067971
   3.83697        3.83697
   5.7385         5.7385
  -6.15176       -6.15176
  -4.08442       -4.08442
  -6.18563       -6.18563
   6.44396        6.44396
   5.63585        5.63585
   1.21604        1.21604
  11.1837        11.1837
   2.29144        2.29144
  -0.995473      -0.995473
   5.22826        5.22826
   9.27205        9.27205
  -7.23457       -7.23457
   6.29887        6.29887
   2.48343        2.48343
  -4.96111       -4.96111
  -5.52811       -5.52811
  -4.40855       -4.40855
  -5.69429       -5.69429
  -1.12765       -1.12765
  -0.22142       -0.22142
  -5.96815       -5.96815
   4.55923        4.55923
  -1.05719       -1.05719
   2.07986        2.07986
   7.77539        7.77539
  -2.03581       -2.03581
   0.270705       0.270705
   0.126658       0.126658
  -6.1672        -6.1672
 -16.0576       -16.0576
   0.635198       0.635198
   8.55006        8.55006
  -2.93081       -2.93081
  -1.7657        -1.7657
  -0.37886       -0.37886
  -2.4086        -2.4086
   1.41889        1.41889
  -1.40539       -1.40539
   0.963807       0.963807
  -2.14947       -2.14947
  -6.31832       -6.31832
  -4.30827       -4.30827
   6.2609         6.2609
  -8.36351       -8.36351
   4.28564        4.28564
   0.646361       0.646361
   4.60485        4.60485
  -3.1664        -3.1664
  -0.611618      -0.611618
  -9.53534       -9.53534
   1.92275        1.92275
  -8.1521        -8.1521
   0.101441       0.101441
   0.399002       0.399002
  -2.04551       -2.04551
  -4.5564        -4.5564
   3.0555         3.0555
   0.992401       0.992401
  -5.62638       -5.62638
  -0.46873       -0.46873
  -6.86208       -6.86208
  -2.77108       -2.77108
   3.51118        3.51118
   0.885266       0.885266
   3.65701        3.65701
   6.88336        6.88336
  -7.25948       -7.25948
   7.31435        7.31435
  -6.57357       -6.57357
   3.67947        3.67947
   4.80901        4.80901
  -2.80342       -2.80342
   5.78724        5.78724
   5.30985        5.30985
   7.24724        7.24724
  -1.30439       -1.30439
   2.50975        2.50975
   5.28538        5.28538
  -3.91583       -3.91583
   2.98722        2.98722
   5.31167        5.31167
  -0.596966      -0.596966
  -4.94141       -4.94141
   4.59005        4.59005
   1.3813         1.3813
   4.0611         4.0611
  -0.747616      -0.747616
  -3.1697        -3.1697
  -1.70787       -1.70787
  -2.43542       -2.43542
  -5.86823       -5.86823
 -10.9093       -10.9093
   5.20087        5.20087
  -6.40378       -6.40378
   1.5149         1.5149
  -6.52874       -6.52874
  -5.69743       -5.69743
   1.06819        1.06819
  -7.31776       -7.31776
   3.69649        3.69649
  -4.21319       -4.21319
  -4.91507       -4.91507
   5.44776        5.44776
  -0.708927      -0.708927
   1.94895        1.94895
   2.90927        2.90927
  -2.82547       -2.82547
  -1.79858       -1.79858
 -15.6727       -15.6727
  -0.308918      -0.308918
   2.61943        2.61943
  -3.89041       -3.89041
  -1.84684       -1.84684
  -6.80446       -6.80446
   3.97398        3.97398
   2.31201        2.31201
   4.29417        4.29417
  -1.24479       -1.24479
   4.25927        4.25927
  -1.96968       -1.96968
   0.703519       0.703519
   2.06517        2.06517
   0.920347       0.920347
   6.22843        6.22843
   1.86167        1.86167
   0.43407        0.43407
   1.25225        1.25225
  -0.00512493    -0.00512493
  -1.70887       -1.70887
   0.725693       0.725693
   6.11604        6.11604
  -5.87059       -5.87059
   3.26102        3.26102
   2.0488         2.0488
  -0.0544172     -0.0544172
   2.57295        2.57295
  -1.10578       -1.10578
   2.43904        2.43904
  -2.34604       -2.34604
   3.2098         3.2098
   2.16089        2.16089
  -9.35001       -9.35001
   9.43924        9.43924
   0.916747       0.916747
   2.59533        2.59533
  -1.84596       -1.84596
   1.02889        1.02889
   0.755944       0.755944
   8.28274        8.28274
  -3.21136       -3.21136
   1.24897        1.24897
  -0.363928      -0.363928
   2.37533        2.37533
  -1.5794        -1.5794
   6.67417        6.67417
  -4.4632        -4.4632
   8.53731        8.53731
  -1.16526       -1.16526
  -0.51467       -0.51467
  -4.91688       -4.91688
   7.17741        7.17741
   4.61708        4.61708
  -2.41511       -2.41511
 -11.5234       -11.5234
   2.61523        2.61523
   4.7703         4.7703
   6.72381        6.72381
   5.65388        5.65388
  -4.23963       -4.23963
   0.925176       0.925176
   1.98862        1.98862
  -6.14466       -6.14466
   2.76728        2.76728
  -0.83598       -0.83598
  -4.22593       -4.22593
   5.99083        5.99083
  -4.886         -4.886
   4.37801        4.37801
   5.77761        5.77761
   3.38352        3.38352
  -0.311291      -0.311291
   8.26669        8.26669
  -4.94787       -4.94787
  -9.62034       -9.62034
   2.37023        2.37023
   3.41718        3.41718
  -2.43368       -2.43368
   3.5898         3.5898
  -1.21973       -1.21973
   0.0350305      0.0350305
  -4.33097       -4.33097
  -3.41432       -3.41432
   2.59161        2.59161
  -2.11239       -2.11239
  -1.0801        -1.0801
  -3.27061       -3.27061
  -0.34025       -0.34025
  -6.40563       -6.40563
  -0.522305      -0.522305
   4.63382        4.63382
   1.5154         1.5154
   0.968893       0.968893
   2.79354        2.79354
  -0.829942      -0.829942
  -1.76388       -1.76388
  -6.64903       -6.64903
  -8.52588       -8.52588
   2.70798        2.70798
   6.78381        6.78381
  -5.67891       -5.67891
  -0.0588557     -0.0588557
  -4.12923       -4.12923
  -2.70431       -2.70431
  -0.12131       -0.12131
   6.59494        6.59494
   0.830427       0.830427
   3.40436        3.40436
   6.98828        6.98828
  -2.33332       -2.33332
   5.85244        5.85244
 -10.0398       -10.0398
  -0.242519      -0.242519
  -3.38719       -3.38719
   2.74288        2.74288
   3.82961        3.82961
  -6.85166       -6.85166
  -0.345431      -0.345431
  -3.03082       -3.03082
   1.68089        1.68089
  -0.785036      -0.785036
  -2.92804       -2.92804
   1.03727        1.03727
   5.51647        5.51647
  -2.15538       -2.15538
  -6.20918       -6.20918
  -0.986195      -0.986195
  -4.4207        -4.4207
  -0.314791      -0.314791
  -6.64843       -6.64843
   1.255          1.255
   4.39107        4.39107
   2.20706        2.20706
  -1.894         -1.894
  -3.01471       -3.01471
  -0.0623641     -0.0623641
  -5.76316       -5.76316
  -2.45987       -2.45987
  -2.09262       -2.09262
   0.0458748      0.0458748
   5.09539        5.09539
  -3.80431       -3.80431
  -3.90738       -3.90738
  -6.48843       -6.48843
  -2.58373       -2.58373
  -6.38764       -6.38764
   7.38858        7.38858
   0.492176       0.492176
   8.79347        8.79347
   2.04442        2.04442
  -0.216083      -0.216083
  11.3375        11.3375
  -3.4177        -3.4177
   3.90111        3.90111
   4.92081        4.92081
   4.45964        4.45964
  11.1458        11.1458
  -2.2688        -2.2688
  -4.43463       -4.43463
  -4.22186       -4.22186
  -5.93987       -5.93987
   3.4437         3.4437
  -5.60816       -5.60816
  -8.04401       -8.04401
  -4.95256       -4.95256
   3.88283        3.88283
  -0.173935      -0.173935
  -2.63243       -2.63243
  -1.03812       -1.03812
  -9.14078       -9.14078
  -6.1411        -6.1411
   3.4284         3.4284
  -9.8305        -9.8305
   6.76115        6.76115
 -11.3646       -11.3646
  -5.7296        -5.7296
  -2.41831       -2.41831
  -5.21505       -5.21505
  10.4347        10.4347
   2.06721        2.06721
   1.02265        1.02265
  -6.93537       -6.93537
   1.28707        1.28707
   0.939615       0.939615
  11.262         11.262
   1.2805         1.2805
   4.8619         4.8619
   3.15836        3.15836
  -5.18747       -5.18747
  -2.98078       -2.98078
  -2.0489        -2.0489
  -2.85634       -2.85634
  -4.56059       -4.56059
  -4.0715        -4.0715
   0.469543       0.469543
  -2.05188       -2.05188
  -2.79567       -2.79567
   3.82027        3.82027
   2.55175        2.55175
  -0.468207      -0.468207
  -5.65994       -5.65994
   2.13508        2.13508
  -3.17019       -3.17019
   6.53032        6.53032
  -4.98714       -4.98714
  -1.94956       -1.94956
  -3.08465       -3.08465
   8.11664        8.11664
   8.86283        8.86283
   0.84108        0.84108
   5.22353        5.22353
  -3.45671       -3.45671
  -1.38725       -1.38725
   1.35206        1.35206
 -10.4407       -10.4407
  -2.20051       -2.20051
  -0.228019      -0.228019
  -1.38039       -1.38039
  11.1342        11.1342
   5.17568        5.17568
  -4.54852       -4.54852
  -1.26392       -1.26392
   5.69792        5.69792
  -4.90866       -4.90866
   2.84526        2.84526
  10.9699        10.9699
  12.9756        12.9756
   8.48223        8.48223
   2.11902        2.11902
   3.74471        3.74471
  -5.14437       -5.14437
 -14.7206       -14.7206
   3.01028        3.01028
  -2.67988       -2.67988
  -2.88296       -2.88296
  -4.95895       -4.95895
  -1.82286       -1.82286
   5.23419        5.23419
  -2.23867       -2.23867
   0.610838       0.610838
   2.09177        2.09177
   5.74677        5.74677
   3.6242         3.6242
   2.0758         2.0758
  -2.85159       -2.85159
  -3.93562       -3.93562
   3.85649        3.85649
  -5.75638       -5.75638
  -7.07444       -7.07444
   0.907402       0.907402
  -8.92532       -8.92532
  -4.09782       -4.09782
   1.85777        1.85777
   5.73041        5.73041
  -2.17118       -2.17118
  -3.4713        -3.4713
   7.95825        7.95825
   9.10838        9.10838
   1.80182        1.80182
  -0.54593       -0.54593
  -4.89919       -4.89919
  -2.97982       -2.97982
   0.807424       0.807424
  -2.27          -2.27
 -13.2338       -13.2338
  -3.94367       -3.94367
  -5.72938       -5.72938
  -2.42243       -2.42243
  -3.69581       -3.69581
  -4.71307       -4.71307
   1.38983        1.38983
  -5.37869       -5.37869
  -6.82815       -6.82815
   2.73203        2.73203
  13.6495        13.6495
  -6.29731       -6.29731
  -8.43712       -8.43712
  14.1567        14.1567
  -0.978804      -0.978804
   1.26264        1.26264
  -9.25575       -9.25575
  -8.10968       -8.10968
  -3.98015       -3.98015
   6.60273        6.60273
  -3.98373       -3.98373
   1.35817        1.35817
   1.20988        1.20988
   1.53069        1.53069
   4.08368        4.08368
  -2.38429       -2.38429
  -4.67381       -4.67381
  -5.49726       -5.49726
   0.657715       0.657715
  -0.00123905    -0.00123905
   4.62712        4.62712
  -0.317445      -0.317445
  -5.08829       -5.08829
  -9.85674       -9.85674
   5.31787        5.31787
   1.61793        1.61793
   3.9901         3.9901
  -1.04243       -1.04243
  -3.73679       -3.73679
   0.670282       0.670282
   9.03148        9.03148
  -4.77058       -4.77058
   8.60147        8.60147
  -0.664744      -0.664744
   1.97711        1.97711
  -5.35794       -5.35794
  -9.70033       -9.70033
  10.7781        10.7781
   1.96443        1.96443
   1.84069        1.84069
 -12.0109       -12.0109
   2.08404        2.08404
   3.64031        3.64031
   8.65585        8.65585
 -11.8355       -11.8355
   9.89404        9.89404
   0.279063       0.279063
  -0.315296      -0.315296
   3.74263        3.74263
   6.54645        6.54645
   5.43941        5.43941
   4.83252        4.83252
   1.70716        1.70716
  -3.27497       -3.27497
  -3.07764       -3.07764
   9.25309        9.25309
  -1.69559       -1.69559
  10.1694        10.1694
  -3.42523       -3.42523
   6.39435        6.39435
   2.18084        2.18084
   1.33177        1.33177
  -0.709393      -0.709393
   1.44799        1.44799
   0.881759       0.881759
  -2.35085       -2.35085
  -1.91407       -1.91407
   0.302603       0.302603
   1.40288        1.40288
  -2.37323       -2.37323
  -7.74084       -7.74084
  -7.73224       -7.73224
   2.8793         2.8793
   6.62065        6.62065
   1.4654         1.4654
  -0.982735      -0.982735
  -0.97328       -0.97328
  -8.38882       -8.38882
   8.74643        8.74643
  -7.86996       -7.86996
   3.25655        3.25655
   2.78551        2.78551
  -5.17511       -5.17511
   4.90515        4.90515
   0.28899        0.28899
   3.57292        3.57292
  -5.25376       -5.25376
  -8.57274       -8.57274
  -1.18267       -1.18267
  37.4072        37.4072
  -4.00801       -4.00801
   4.8073         4.8073
  -4.45001       -4.45001
   7.66024        7.66024
  -4.47725       -4.47725
 -10.2209       -10.2209
  -4.80026       -4.80026
  -0.64446       -0.64446
  -0.899171      -0.899171
   1.09833        1.09833
  -0.988097      -0.988097
   2.82126        2.82126
  -8.19269       -8.19269
  -2.64922       -2.64922
  -9.16004       -9.16004
  -2.39588       -2.39588
  -4.72025       -4.72025
   2.34077        2.34077
   3.83879        3.83879
   1.9499         1.9499
  -0.361603      -0.361603
   7.79929        7.79929
   2.34774        2.34774
  -8.21052       -8.21052
  -2.02077       -2.02077
  -1.58017       -1.58017
  -0.410542      -0.410542
 -10.7206       -10.7206
   3.26874        3.26874
   2.80972        2.80972
   0.0906836      0.0906836
  -1.64773       -1.64773
   6.49353        6.49353
  -0.791109      -0.791109
   4.71404        4.71404
   0.0741314      0.0741314
  -0.414415      -0.414415
   6.84572        6.84572
  -0.367457      -0.367457
   1.17563        1.17563
   0.51039        0.51039
   4.40348        4.40348
   0.978932       0.978932
   3.79206        3.79206
   4.57632        4.57632
   2.77883        2.77883
   0.490867       0.490867
  -0.151798      -0.151798
   6.72243        6.72243
   4.77773        4.77773
  -0.50633       -0.50633
  -8.08639       -8.08639
   4.88619        4.88619
  -2.07669       -2.07669
  -2.24093       -2.24093
   1.72994        1.72994
  -7.45157       -7.45157
 -12.1192       -12.1192
   1.4328         1.4328
  -8.14432       -8.14432
  -6.25485       -6.25485
   0.516865       0.516865
   7.11864        7.11864
  -0.616318      -0.616318
  -0.761916      -0.761916
  -5.99496       -5.99496
  10.4321        10.4321
  -0.516052      -0.516052
  -5.68287       -5.68287
  -4.15541       -4.15541
   1.56619        1.56619
 -20.8292       -20.8292
   0.788033       0.788033
   3.34264        3.34264
   3.70493        3.70493
  -0.0822138     -0.0822138
   2.31304        2.31304
  -1.69352       -1.69352
   2.10396        2.10396
   7.2613         7.2613
  -1.81799       -1.81799
  -2.09968       -2.09968
  -3.8336        -3.8336
  -3.93478       -3.93478
   3.3059         3.3059
   4.19189        4.19189
  -1.93794       -1.93794
   2.7117         2.7117
   9.43261        9.43261
  -1.83318       -1.83318
  -1.12685       -1.12685
   2.40725        2.40725
   7.50947        7.50947
   7.65688        7.65688
  -5.02792       -5.02792
  -2.55777       -2.55777
  -1.9946        -1.9946
  -0.126192      -0.126192
  -3.30905       -3.30905
  -0.209775      -0.209775
   9.06409        9.06409
  -3.79201       -3.79201
   8.80185        8.80185
  -1.59367       -1.59367
  -2.49213       -2.49213
  -3.5242        -3.5242
   2.4892         2.4892
   5.68222        5.68222
   4.29073        4.29073
   0.490494       0.490494
   3.31313        3.31313
   8.27344        8.27344
   1.44936        1.44936
   5.94283        5.94283
  -5.90497       -5.90497
   0.316931       0.316931
   1.93975        1.93975
  -1.33405       -1.33405
  -4.17957       -4.17957
   2.45999        2.45999
 -10.0965       -10.0965
   0.648564       0.648564
  -0.745957      -0.745957
  -6.08922       -6.08922
  -6.45851       -6.45851
   2.70093        2.70093
  -2.59331       -2.59331
  -2.73319       -2.73319
  -6.50584       -6.50584
   4.14167        4.14167
   6.78757        6.78757
   4.63335        4.63335
   2.01754        2.01754
   3.97717        3.97717
   2.73775        2.73775
   2.04299        2.04299
   7.03044        7.03044
  -8.59414       -8.59414
  -4.19956       -4.19956
   0.0135157      0.0135157
  -5.45393       -5.45393
   2.75578        2.75578
   0.730278       0.730278
  -0.410035      -0.410035
  10.7831        10.7831
  -2.82537       -2.82537
   1.85601        1.85601
   1.68496        1.68496
   2.75249        2.75249
   9.40848        9.40848
   1.6032         1.6032
  -3.91263       -3.91263
   1.12247        1.12247
  -3.46516       -3.46516
  -1.48668       -1.48668
   6.7676         6.7676
  -5.76927       -5.76927
  -2.19943       -2.19943
  -1.61329       -1.61329
   3.35791        3.35791
  -7.80737       -7.80737
   3.06567        3.06567
 -12.2037       -12.2037
  12.541         12.541
   4.42316        4.42316
   6.48419        6.48419
   1.17664        1.17664
   2.97986        2.97986
  -8.63966       -8.63966
   0.241757       0.241757
  -5.03654       -5.03654
  -1.94594       -1.94594
  12.8093        12.8093
  -3.58644       -3.58644
  -3.35952       -3.35952
  -0.864134      -0.864134
 -12.4807       -12.4807
  -1.69909       -1.69909
  -5.67676       -5.67676
 -10.6435       -10.6435
  -3.86815       -3.86815
   4.20674        4.20674
  -4.94992       -4.94992
   7.63289        7.63289
  -5.5226        -5.5226
   1.58362        1.58362
   1.14864        1.14864
   5.98635        5.98635
  11.9692        11.9692
  -0.208588      -0.208588
  -0.177219      -0.177219
   6.35143        6.35143
  -2.21028       -2.21028
   0.693657       0.693657
   2.66882        2.66882
  -0.494413      -0.494413
  10.9482        10.9482
   2.9522         2.9522
   1.69427        1.69427
  -5.54007       -5.54007
  -1.44208       -1.44208
  -2.75377       -2.75377
   7.62773        7.62773
  -0.0991657     -0.0991657
   0.541024       0.541024
   0.383422       0.383422
  -6.28538       -6.28538
  -3.63239       -3.63239
   5.54891        5.54891
   4.38377        4.38377
  -4.21607       -4.21607
  -1.58462       -1.58462
   1.99568        1.99568
   1.70177        1.70177
   1.65142        1.65142
   1.79811        1.79811
  -6.82605       -6.82605
   3.65159        3.65159
   2.60935        2.60935
  -2.91237       -2.91237
  -1.56808       -1.56808
  -3.07334       -3.07334
   0.883426       0.883426
  -1.59697       -1.59697
   4.44432        4.44432
  -2.72255       -2.72255
  -0.853149      -0.853149
  -0.132598      -0.132598
  -0.63629       -0.63629
  -3.69308       -3.69308
  -7.18449       -7.18449
   1.20547        1.20547
  14.3427        14.3427
   5.08288        5.08288
   0.957041       0.957041
   0.153537       0.153537
  -7.14906       -7.14906
  -8.78572       -8.78572
   4.05049        4.05049
   3.22929        3.22929
  -3.34601       -3.34601
   3.86442        3.86442
  -2.80641       -2.80641
   6.51055        6.51055
  -4.58706       -4.58706
  -1.51146       -1.51146
   3.88212        3.88212
   1.89549        1.89549
   3.50062        3.50062
  -1.43005       -1.43005
  -2.91969       -2.91969
  -6.52573       -6.52573
  -3.8843        -3.8843
  -8.34716       -8.34716
  -7.42192       -7.42192
  -3.98985       -3.98985
  15.526         15.526
   8.70318        8.70318
  -1.10105       -1.10105
   2.14694        2.14694
   7.71484        7.71484
  -0.0260442     -0.0260442
  -3.31138       -3.31138
   1.67906        1.67906
  -0.083112      -0.083112
  -8.42905       -8.42905
  -8.82729       -8.82729
  11.2859        11.2859
  -8.07136       -8.07136
  -3.9371        -3.9371
  -4.63176       -4.63176
  -1.23605       -1.23605
  -2.08565       -2.08565
   1.93918        1.93918
 -12.5031       -12.5031
  -0.442281      -0.442281
  -5.50289       -5.50289
  -0.815112      -0.815112
   0.0898735      0.0898735
   4.69373        4.69373
  -7.22004       -7.22004
   0.543294       0.543294
   4.2932         4.2932
   2.12984        2.12984
  -4.42752       -4.42752
   3.03694        3.03694
  -3.73337       -3.73337
 -12.0483       -12.0483
  -5.99704       -5.99704
   0.0707967      0.0707967
  -4.52239       -4.52239
   3.65625        3.65625
  -5.61903       -5.61903
   9.78971        9.78971
   8.47575        8.47575
  -0.320966      -0.320966
  -7.10339       -7.10339
   0.485669       0.485669
   3.19439        3.19439
  -0.411976      -0.411976
  -0.782875      -0.782875
  16.4086        16.4086
  -2.67312       -2.67312
   0.73424        0.73424
   8.32014        8.32014
  -1.24665       -1.24665
   3.70031        3.70031
  -6.22155       -6.22155
  -6.34804       -6.34804
  -4.84631       -4.84631
   7.19111        7.19111
   2.58937        2.58937
   2.12044        2.12044
  -0.304369      -0.304369
 -11.5161       -11.5161
  -4.75933       -4.75933
  -5.40287       -5.40287
 -14.7511       -14.7511
 -11.3269       -11.3269
  -3.40961       -3.40961
  -8.36998       -8.36998
  -7.86816       -7.86816
   3.46638        3.46638
   5.10745        5.10745
   9.12589        9.12589
   4.53119        4.53119
  -0.0952322     -0.0952322
  -1.67069       -1.67069
   1.48937        1.48937
   2.1548         2.1548
  -0.680895      -0.680895
   6.00943        6.00943
  -6.23597       -6.23597
  15.2635        15.2635
  -5.39621       -5.39621
   2.9004         2.9004
  -7.2031        -7.2031
   0.188095       0.188095
  -5.65511       -5.65511
   8.80472        8.80472
   4.77116        4.77116
  -0.320718      -0.320718
  -0.094774      -0.094774
   4.24892        4.24892
  -0.729715      -0.729715
   3.46906        3.46906
  -4.86913       -4.86913
  -2.05092       -2.05092
   3.24008        3.24008
   2.67334        2.67334
   5.41008        5.41008
   4.61387        4.61387
 -11.9338       -11.9338
   2.15538        2.15538
   3.39914        3.39914
   2.71216        2.71216
   6.79031        6.79031
  -0.750493      -0.750493
  -0.683416      -0.683416
   7.23875        7.23875
   4.67949        4.67949
  -2.16467       -2.16467
   3.64787        3.64787
  -1.27823       -1.27823
  -1.43992       -1.43992
   3.183          3.183
  -8.60412       -8.60412
  -5.42757       -5.42757
  -0.564214      -0.564214
  -1.17837       -1.17837
   2.45248        2.45248
   3.60909        3.60909
   2.61183        2.61183
   5.20279        5.20279
  -1.07145       -1.07145
  -0.919519      -0.919519
   3.89898        3.89898
   3.72175        3.72175
  -9.9673        -9.9673
   1.50607        1.50607
  -0.456562      -0.456562
  10.9984        10.9984
  -2.18673       -2.18673
  -7.39159       -7.39159
  -5.54389       -5.54389
   2.6353         2.6353
   6.87535        6.87535
 -10.4019       -10.4019
  -5.51375       -5.51375
  -3.33244       -3.33244
   7.60358        7.60358
  -9.48529       -9.48529
  -0.514099      -0.514099
   6.20569        6.20569
  -4.60198       -4.60198
  -1.28686       -1.28686
  -0.383981      -0.383981
  -0.173934      -0.173934
  -7.97782       -7.97782
   5.9926         5.9926
  -3.7357        -3.7357
  -7.77841       -7.77841
   3.09245        3.09245
  -3.70421       -3.70421
  -1.50012       -1.50012
  -3.90181       -3.90181
   0.183002       0.183002
  -4.72374       -4.72374
  -3.36966       -3.36966
   8.23642        8.23642
   0.387898       0.387898
  -2.53048       -2.53048
   4.46348        4.46348
  -0.932844      -0.932844
  -1.76804       -1.76804
  -0.390175      -0.390175
   8.28101        8.28101
   8.66959        8.66959
   2.47585        2.47585
   6.33837        6.33837
   3.05846        3.05846
   6.43047        6.43047
   0.167477       0.167477
   0.615034       0.615034
  -8.467         -8.467
   2.15566        2.15566
   6.59172        6.59172
  -8.30068       -8.30068
  -2.92268       -2.92268
  -1.14616       -1.14616
   3.864          3.864
  -8.07267       -8.07267
   0.382952       0.382952
   4.79087        4.79087
   7.87692        7.87692
  -1.27352       -1.27352
  -0.439992      -0.439992
  -0.361056      -0.361056
   5.51463        5.51463
   4.10827        4.10827
  -1.36056       -1.36056
 -10.9063       -10.9063
  -3.12566       -3.12566
  -1.52612       -1.52612
   2.47429        2.47429
   1.92973        1.92973
   6.05399        6.05399
   6.35717        6.35717
  -6.54112       -6.54112
   0.16752        0.16752
  -0.581192      -0.581192
  -3.91981       -3.91981
   3.29046        3.29046
  -9.85289       -9.85289
  -1.68008       -1.68008
  -0.294261      -0.294261
  -2.33446       -2.33446
   8.72203        8.72203
  -7.53754       -7.53754
   1.8548         1.8548
   0.0863562      0.0863562
   3.71224        3.71224
  -2.72156       -2.72156
   6.92717        6.92717
   4.22066        4.22066
   2.9384         2.9384
  -0.436476      -0.436476
   7.94505        7.94505
   3.35167        3.35167
   4.57606        4.57606
  -1.94551       -1.94551
   7.26891        7.26891
   5.7114         5.7114
  -4.8975        -4.8975
   0.24802        0.24802
   4.4272         4.4272
   3.21714        3.21714
  -2.75997       -2.75997
   3.0239         3.0239
   6.00743        6.00743
   1.95157        1.95157
  -8.23524       -8.23524
  -0.0388194     -0.0388194
  -1.59723       -1.59723
 -15.7227       -15.7227
   5.01363        5.01363
   2.59661        2.59661
   0.344503       0.344503
   7.85727        7.85727
   0.142462       0.142462
  -3.54743       -3.54743
  -4.18558       -4.18558
   3.96172        3.96172
  -0.376684      -0.376684
   3.78763        3.78763
  -1.58384       -1.58384
  15.837         15.837
  -0.887404      -0.887404
   0.855016       0.855016
  11.1701        11.1701
   5.15206        5.15206
   6.83176        6.83176
  -0.91331       -0.91331
 -10.3398       -10.3398
   2.48231        2.48231
  -2.03572       -2.03572
   1.09096        1.09096
  -0.162198      -0.162198
  -7.32758       -7.32758
  -6.97941       -6.97941
   5.98831        5.98831
  -7.43703       -7.43703
  -8.97936       -8.97936
   0.676949       0.676949
   1.37291        1.37291
   4.41159        4.41159
   2.45643        2.45643
   2.79374        2.79374
   2.36712        2.36712
  -7.74483       -7.74483
   0.602922       0.602922
  -2.48544       -2.48544
   0.299035       0.299035
   6.77695        6.77695
   1.44763        1.44763
   1.94637        1.94637
  -4.04181       -4.04181
  16.3509        16.3509
   6.4273         6.4273
   5.41235        5.41235
  -5.91387       -5.91387
  -6.06301       -6.06301
   3.4536         3.4536
  -3.39128       -3.39128
  11.299         11.299
   2.62685        2.62685
   1.00866        1.00866
  10.6766        10.6766
  -0.805083      -0.805083
   3.91073        3.91073
   3.67201        3.67201
  -9.14116       -9.14116
  15.6406        15.6406
   3.22084        3.22084
  -2.90513       -2.90513
   4.58966        4.58966
   0.0983211      0.0983211
   2.35908        2.35908
   0.658109       0.658109
   2.37478        2.37478
  -6.70679       -6.70679
   6.08307        6.08307
 -29.6624       -29.6624
   1.55578        1.55578
   5.31311        5.31311
  -5.40681       -5.40681
   1.80228        1.80228
   4.50431        4.50431
   7.25673        7.25673
   5.89811        5.89811
  -2.92888       -2.92888
   7.48853        7.48853
  -1.67318       -1.67318
   0.974302       0.974302
  -8.10178       -8.10178
   3.29435        3.29435
  -1.64519       -1.64519
  -7.08854       -7.08854
   6.68891        6.68891
  -5.69927       -5.69927
  -3.51768       -3.51768
  11.2895        11.2895
  -0.828568      -0.828568
   5.53562        5.53562
  -0.358066      -0.358066
  -5.92559       -5.92559
   4.39224        4.39224
  -5.1225        -5.1225
  -9.51174       -9.51174
   9.80076        9.80076
  -1.85858       -1.85858
   6.95181        6.95181
  -1.71297       -1.71297
  -0.275297      -0.275297
  -0.860135      -0.860135
  -0.484906      -0.484906
   5.71425        5.71425
   2.74639        2.74639
  -8.40417       -8.40417
  -1.84935       -1.84935
   2.94526        2.94526
  10.708         10.708
   0.892511       0.892511
  -1.36773       -1.36773
  -7.25911       -7.25911
   3.91428        3.91428
  -0.776027      -0.776027
   3.44102        3.44102
  -4.87806       -4.87806
   3.65101        3.65101
  -3.01077       -3.01077
   1.17918        1.17918
   5.82266        5.82266
   8.52564        8.52564
   4.35296        4.35296
  -2.94897       -2.94897
  -4.19366       -4.19366
  -4.7939        -4.7939
   3.44038        3.44038
  -7.87089       -7.87089
  -3.18931       -3.18931
  -6.65708       -6.65708
   1.09687        1.09687
  -4.36662       -4.36662
   2.90783        2.90783
   4.66889        4.66889
  -1.26146       -1.26146
  -2.01469       -2.01469
  -2.44566       -2.44566
  -2.15098       -2.15098
   3.4006         3.4006
   0.0396139      0.0396139
   2.29469        2.29469
  -7.62709       -7.62709
   7.18738        7.18738
   1.45481        1.45481
   2.37791        2.37791
  -5.37208       -5.37208
  -0.0612415     -0.0612415
  -1.46115       -1.46115
   4.29624        4.29624
   3.25993        3.25993
   2.42986        2.42986
   6.56133        6.56133
  -2.07349       -2.07349
   5.61643        5.61643
   5.48251        5.48251
  -0.703666      -0.703666
  -5.09456       -5.09456
   0.57249        0.57249
   4.28577        4.28577
   2.468          2.468
 -10.013        -10.013
  -3.26046       -3.26046
  -7.91038       -7.91038
  -2.03302       -2.03302
   3.49234        3.49234
  -1.2481        -1.2481
  -1.87417       -1.87417
  -1.93016       -1.93016
   2.14307        2.14307
  -9.0722        -9.0722
   2.03124        2.03124
  -0.938906      -0.938906
   0.817464       0.817464
   2.23636        2.23636
   1.3076         1.3076
   4.90629        4.90629
   2.16603        2.16603
   5.84398        5.84398
  -6.56748       -6.56748
   7.22968        7.22968
   0.664381       0.664381
  11.2001        11.2001
  -4.98902       -4.98902
   0.841822       0.841822
  -1.35522       -1.35522
  -2.43996       -2.43996
   5.14732        5.14732
  -7.50974       -7.50974
   5.73113        5.73113
  -2.72015       -2.72015
  -5.04474       -5.04474
 -13.1          -13.1
   0.0777815      0.0777815
   7.85631        7.85631
  -0.323243      -0.323243
  -2.97974       -2.97974
   0.925187       0.925187
   5.77219        5.77219
   4.39868        4.39868
   2.22326        2.22326
   1.79052        1.79052
  -3.37507       -3.37507
  -4.08645       -4.08645
   5.59349        5.59349
  11.879         11.879
  -0.8099        -0.8099
  16.6866        16.6866
   2.85772        2.85772
   3.73902        3.73902
  -0.406009      -0.406009
   7.49033        7.49033
  -1.01733       -1.01733
   4.03678        4.03678
   4.91574        4.91574
  14.6191        14.6191
  -1.18215       -1.18215
  -2.79895       -2.79895
  -5.16604       -5.16604
  -2.24596       -2.24596
   1.83945        1.83945
   1.72673        1.72673
 -23.2963       -23.2963
  -0.623748      -0.623748
  -2.8419        -2.8419
   6.56374        6.56374
  10.3431        10.3431
   5.28302        5.28302
   3.12716        3.12716
   8.41242        8.41242
   0.416003       0.416003
  -2.43236       -2.43236
  -1.63284       -1.63284
   5.3806         5.3806
   9.39975        9.39975
   4.44496        4.44496
  -3.01441       -3.01441
  -1.33538       -1.33538
   2.23541        2.23541
  -4.30131       -4.30131
  -1.20324       -1.20324
   4.79406        4.79406
   0.692551       0.692551
  -2.20403       -2.20403
   0.12931        0.12931
   0.842875       0.842875
   0.29791        0.29791
   6.59639        6.59639
   8.6591         8.6591
   2.07311        2.07311
  -6.48842       -6.48842
   2.70007        2.70007
  -0.143695      -0.143695
   3.99651        3.99651
   6.86089        6.86089
  -2.54281       -2.54281
  -5.085         -5.085
   3.61747        3.61747
   2.09466        2.09466
   3.35667        3.35667
   7.38405        7.38405
   0.816999       0.816999
  -0.564258      -0.564258
   2.46281        2.46281
  -0.081471      -0.081471
  12.0933        12.0933
   9.45364        9.45364
   0.303564       0.303564
  -2.20687       -2.20687
   1.90101        1.90101
  -2.65606       -2.65606
 -11.3589       -11.3589
  -1.68249       -1.68249
  -1.25813       -1.25813
  -0.96125       -0.96125
  -2.84666       -2.84666
   1.18914        1.18914
   0.211945       0.211945
  -4.8988        -4.8988
   0.894798       0.894798
   3.9685         3.9685
  -0.852608      -0.852608
   3.37537        3.37537
  -0.847579      -0.847579
  -4.37006       -4.37006
  -4.12787       -4.12787
   4.37155        4.37155
  -7.86631       -7.86631
  -3.59755       -3.59755
  -2.55397       -2.55397
   4.25921        4.25921
   2.21721        2.21721
   5.72299        5.72299
   8.32362        8.32362
  14.4057        14.4057
   1.49376        1.49376
   3.108          3.108
  -1.34388       -1.34388
   3.77816        3.77816
   5.69761        5.69761
   0.255491       0.255491
   4.15979        4.15979
 -14.6016       -14.6016
   3.1475         3.1475
   2.86732        2.86732
  -2.7875        -2.7875
  -8.78827       -8.78827
  -1.38068       -1.38068
  -2.74156       -2.74156
  -4.82257       -4.82257
  -4.64984       -4.64984
  -0.462036      -0.462036
   2.36274        2.36274
   2.73927        2.73927
  -4.01583       -4.01583
  -4.20256       -4.20256
   7.33455        7.33455
   7.53557        7.53557
   3.2532         3.2532
  -0.556551      -0.556551
   4.39618        4.39618
   2.92025        2.92025
 -49.4395       -49.4395
   1.84066        1.84066
  -6.03682       -6.03682
   9.70956        9.70956
  12.18          12.18
  -0.134471      -0.134471
   0.388477       0.388477
  -4.30526       -4.30526
   3.98614        3.98614
  -3.20351       -3.20351
   3.81764        3.81764
   5.34853        5.34853
   0.382215       0.382215
  -0.473372      -0.473372
  -4.4073        -4.4073
 -10.1129       -10.1129
  -6.82482       -6.82482
   5.39935        5.39935
  -0.664077      -0.664077
   7.75577        7.75577
  -5.565         -5.565
  -2.28518       -2.28518
  -3.09472       -3.09472
   6.0196         6.0196
  -1.32035       -1.32035
   2.5721         2.5721
  -9.0201        -9.0201
   6.87621        6.87621
   7.57662        7.57662
  -2.42131       -2.42131
  -7.11          -7.11
   1.5457         1.5457
   1.38686        1.38686
  -1.67077       -1.67077
   5.34357        5.34357
  -5.22992       -5.22992
  -5.50112       -5.50112
  -0.820436      -0.820436
  -6.85987       -6.85987
   4.36935        4.36935
   8.27737        8.27737
   7.16613        7.16613
   7.21538        7.21538
   0.0297893      0.0297893
  -3.30991       -3.30991
   1.18508        1.18508
  -0.745072      -0.745072
  -1.31153       -1.31153
  -2.57184       -2.57184
  -0.187369      -0.187369
   6.79233        6.79233
   8.04294        8.04294
   3.06986        3.06986
  -5.13761       -5.13761
   0.539648       0.539648
   5.02007        5.02007
   2.67737        2.67737
  -6.69984       -6.69984
   6.76321        6.76321
   6.25102        6.25102
   3.80545        3.80545
  -2.16059       -2.16059
   2.81803        2.81803
   0.447194       0.447194
   1.84756        1.84756
  -6.42528       -6.42528
  -2.23379       -2.23379
  -2.61151       -2.61151
  -2.86143       -2.86143
  -2.94039       -2.94039
  -3.38503       -3.38503
   0.474985       0.474985
  -9.66389       -9.66389
   4.96293        4.96293
  -5.6718        -5.6718
   7.06422        7.06422
  -8.36354       -8.36354
   0.0182466      0.0182466
   9.20883        9.20883
   8.23981        8.23981
  -1.41968       -1.41968
  -1.36057       -1.36057
  -3.99568       -3.99568
   2.51484        2.51484
   5.41846        5.41846
 -10.8511       -10.8511
  -8.41267       -8.41267
   2.04668        2.04668
  -5.61525       -5.61525
  -9.73507       -9.73507
  -0.497102      -0.497102
   4.29467        4.29467
  -1.61424       -1.61424
  -0.818494      -0.818494
  -7.02135       -7.02135
  13.4836        13.4836
  -4.10115       -4.10115
  -8.11914       -8.11914
  -2.79895       -2.79895
  -4.39428       -4.39428
  -0.737467      -0.737467
   1.37013        1.37013
   9.56244        9.56244
   2.92491        2.92491
  -7.13393       -7.13393
  -0.179291      -0.179291
  -6.00313       -6.00313
   7.27104        7.27104
  -1.7103        -1.7103
  -7.84843       -7.84843
  13.7304        13.7304
   2.40973        2.40973
  -7.07755       -7.07755
   1.31745        1.31745
  -9.99271       -9.99271
 -15.4753       -15.4753
   4.38711        4.38711
  -5.41127       -5.41127
  -1.06491       -1.06491
   1.09245        1.09245
  -1.33961       -1.33961
  -4.42681       -4.42681
  -4.44164       -4.44164
  -1.80772       -1.80772
  -5.06035       -5.06035
   0.197369       0.197369
   7.27798        7.27798
  -6.88382       -6.88382
   3.21319        3.21319
   8.04111        8.04111
  -3.94107       -3.94107
   1.79716        1.79716
  -0.2134        -0.2134
   1.36955        1.36955
  13.7009        13.7009
  -7.3497        -7.3497
   1.80078        1.80078
   4.25352        4.25352
  -2.80092       -2.80092
  -3.81295       -3.81295
  -4.92036       -4.92036
   0.856001       0.856001
  -1.26696       -1.26696
   2.65207        2.65207
  -1.01876       -1.01876
   1.50837        1.50837
 -11.5335       -11.5335
   5.80989        5.80989
   2.45606        2.45606
   1.64394        1.64394
   2.73651        2.73651
 -11.1653       -11.1653
  -1.66359       -1.66359
  -0.0317267     -0.0317267
   0.115458       0.115458
   4.43585        4.43585
   1.24902        1.24902
   7.30894        7.30894
  16.7814        16.7814
  -0.456154      -0.456154
  -3.94033       -3.94033
  -4.4947        -4.4947
  -2.52048       -2.52048
   0.0890704      0.0890704
  -4.66338       -4.66338
   3.88142        3.88142
   2.35984        2.35984
   4.84037        4.84037
   6.95444        6.95444
   2.74408        2.74408
  -3.23958       -3.23958
  -0.467292      -0.467292
   6.26367        6.26367
  -1.50588       -1.50588
   4.13389        4.13389
  -2.53819       -2.53819
  -4.4987        -4.4987
 -10.3487       -10.3487
 -14.8297       -14.8297
  -8.48112       -8.48112
   3.95155        3.95155
   1.2289         1.2289
  -4.38025       -4.38025
  -0.61687       -0.61687
  10.8511        10.8511
   1.15556        1.15556
  -2.19768       -2.19768
  -7.66931       -7.66931
   4.72919        4.72919
  -7.6738        -7.6738
  -0.688528      -0.688528
   4.74928        4.74928
   4.92126        4.92126
   0.897546       0.897546
   3.85735        3.85735
   0.201364       0.201364
  -5.62425       -5.62425
  -3.83117       -3.83117
   4.05866        4.05866
   3.10063        3.10063
   2.5224         2.5224
  -1.51274       -1.51274
  -0.683338      -0.683338
  -3.23147       -3.23147
  -4.21268       -4.21268
  -2.21401       -2.21401
   1.57887        1.57887
   0.848257       0.848257
  -5.83704       -5.83704
  -7.00011       -7.00011
   3.16884        3.16884
  -4.44161       -4.44161
  -7.62482       -7.62482
  -0.266943      -0.266943
   0.41761        0.41761
  -7.45144       -7.45144
  -0.211132      -0.211132
   0.276707       0.276707
  16.7781        16.7781
   0.689757       0.689757
  -3.04049       -3.04049
   2.91684        2.91684
   1.97161        1.97161
   3.7721         3.7721
  -1.60698       -1.60698
  -4.18868       -4.18868
   7.66491        7.66491
  -0.64664       -0.64664
  -0.660623      -0.660623
   8.68174        8.68174
   0.282074       0.282074
  -2.85266       -2.85266
  -1.91293       -1.91293
   7.18736        7.18736
 -10.3875       -10.3875
  -1.91603       -1.91603
   6.29739        6.29739
  -0.0375388     -0.0375388
  -1.60576       -1.60576
  -3.22148       -3.22148
  -4.24549       -4.24549
   1.30822        1.30822
   2.52307        2.52307
   0.403345       0.403345
  -0.744478      -0.744478
   2.41241        2.41241
  -4.58098       -4.58098
  -0.791842      -0.791842
   3.73626        3.73626
  -1.43002       -1.43002
   4.30716        4.30716
   3.30255        3.30255
  -4.08011       -4.08011
  -5.07282       -5.07282
  -1.54759       -1.54759
  -2.2305        -2.2305
   6.8791         6.8791
   9.7396         9.7396
  -6.50395       -6.50395
   3.57178        3.57178
   7.08987        7.08987
   6.2669         6.2669
   5.87329        5.87329
   2.36823        2.36823
  -6.16          -6.16
   1.96238        1.96238
   7.31651        7.31651
  -1.5257        -1.5257
  -2.89061       -2.89061
   0.407546       0.407546
   5.10645        5.10645
  11.0716        11.0716
   4.7443         4.7443
  -8.77353       -8.77353
  -0.631177      -0.631177
  -4.36973       -4.36973
   1.48666        1.48666
   7.7678         7.7678
  -2.65407       -2.65407
   4.56869        4.56869
  -0.541163      -0.541163
   2.89543        2.89543
   5.39424        5.39424
  -3.62954       -3.62954
   3.77547        3.77547
  -5.96886       -5.96886
  -4.38947       -4.38947
  -2.96756       -2.96756
   2.28222        2.28222
  -1.08489       -1.08489
   1.74726        1.74726
  -3.46088       -3.46088
  11.9371        11.9371
  -5.02359       -5.02359
   2.51632        2.51632
  -0.0297022     -0.0297022
  -2.60011       -2.60011
   0.254202       0.254202
   9.7949         9.7949
   3.64937        3.64937
  10.0857        10.0857
  -5.36637       -5.36637
   4.11127        4.11127
   8.90571        8.90571
  -5.97219       -5.97219
  -7.21379       -7.21379
  -5.01561       -5.01561
   2.98616        2.98616
   1.99064        1.99064
   0.16465        0.16465
  -4.07902       -4.07902
   4.34018        4.34018
  -2.13528       -2.13528
   2.39903        2.39903
   4.00804        4.00804
  -1.85741       -1.85741
  -7.73083       -7.73083
  -4.21139       -4.21139
   4.65743        4.65743
   0.963549       0.963549
   0.29506        0.29506
   6.05798        6.05798
  12.4428        12.4428
  -0.398651      -0.398651
  -0.584559      -0.584559
   2.75445        2.75445
  -0.207975      -0.207975
   6.11926        6.11926
  -8.66125       -8.66125
   3.07568        3.07568
  -3.19358       -3.19358
  -2.53024       -2.53024
  14.1187        14.1187
  -0.412049      -0.412049
  12.5809        12.5809
   6.26236        6.26236
   5.23037        5.23037
  -0.11356       -0.11356
  -6.62321       -6.62321
  -1.29651       -1.29651
  -1.48734       -1.48734
  13.0753        13.0753
   4.21767        4.21767
  -2.4425        -2.4425
  -0.0901323     -0.0901323
   9.79684        9.79684
   4.74522        4.74522
  -3.34804       -3.34804
   7.37816        7.37816
   2.57938        2.57938
   1.92968        1.92968
   3.75166        3.75166
   5.0617         5.0617
   8.74324        8.74324
  -0.93703       -0.93703
  -1.36031       -1.36031
  -2.5439        -2.5439
   1.56784        1.56784
   2.56237        2.56237
  -1.02578       -1.02578
   6.62085        6.62085
   7.69745        7.69745
   6.26864        6.26864
  -4.20046       -4.20046
  -2.30926       -2.30926
   2.74598        2.74598
   4.11078        4.11078
   2.8455         2.8455
  -3.45407       -3.45407
   2.82327        2.82327
  -1.00356       -1.00356
   8.85974        8.85974
   6.35864        6.35864
  -1.59146       -1.59146
  -0.361996      -0.361996
  -1.25198       -1.25198
   8.2867         8.2867
   0.981644       0.981644
   2.68003        2.68003
   1.10236        1.10236
  -1.63423       -1.63423
  -2.79552       -2.79552
  -6.5718        -6.5718
  -0.257779      -0.257779
  -4.49325       -4.49325
   5.0455         5.0455
  14.4508        14.4508
   3.60407        3.60407
   3.09003        3.09003
  -8.32962       -8.32962
  -1.41178       -1.41178
  12.5777        12.5777
  -2.01342       -2.01342
  -1.48205       -1.48205
   0.967158       0.967158
  -0.532548      -0.532548
  -5.23274       -5.23274
  -1.49702       -1.49702
   0.739607       0.739607
   3.49171        3.49171
  -1.0507        -1.0507
  -7.48299       -7.48299
   7.57395        7.57395
  -3.04813       -3.04813
  16.322         16.322
   7.81441        7.81441
  -3.41529       -3.41529
   2.05401        2.05401
   1.08232        1.08232
  12.5735        12.5735
   0.126572       0.126572
  -6.92158       -6.92158
  -1.4651        -1.4651
  -3.19425       -3.19425
  -1.44093       -1.44093
  -3.82056       -3.82056
   6.72914        6.72914
  -5.46583       -5.46583
  -1.43396       -1.43396
   7.42164        7.42164
   1.00438        1.00438
  -0.41415       -0.41415
  -2.54987       -2.54987
   6.88491        6.88491
   3.84807        3.84807
  -5.62245       -5.62245
   5.24133        5.24133
   7.99514        7.99514
  -2.51593       -2.51593
   8.19568        8.19568
   0.854985       0.854985
  -6.20478       -6.20478
  -2.58235       -2.58235
  -6.51346       -6.51346
  12.8877        12.8877
   8.6194         8.6194
  -6.82669       -6.82669
  -4.67379       -4.67379
   8.13137        8.13137
   0.733511       0.733511
   5.66079        5.66079
  -2.94337       -2.94337
  -3.29462       -3.29462
  -6.3809        -6.3809
  -1.85613       -1.85613
   0.635069       0.635069
   0.432626       0.432626
 -14.6426       -14.6426
   8.05825        8.05825
   6.50637        6.50637
   1.44014        1.44014
  -4.60602       -4.60602
  -6.49137       -6.49137
   6.33163        6.33163
  -1.97616       -1.97616
   0.573379       0.573379
  -2.78039       -2.78039
  -0.140087      -0.140087
   1.52619        1.52619
   6.83379        6.83379
  -0.197981      -0.197981
  -3.00849       -3.00849
  -2.09725       -2.09725
  -2.06883       -2.06883
  -0.328198      -0.328198
  -0.212338      -0.212338
   5.4425         5.4425
   6.48574        6.48574
   2.00073        2.00073
  -3.15642       -3.15642
  -0.0673389     -0.0673389
  -4.19911       -4.19911
   4.5466         4.5466
   3.73221        3.73221
  -1.01059       -1.01059
  -4.29015       -4.29015
   4.9909         4.9909
   3.22397        3.22397
  -1.27984       -1.27984
   2.83358        2.83358
   2.25695        2.25695
   7.2879         7.2879
  -1.47955       -1.47955
  12.7627        12.7627
  -3.72449       -3.72449
   3.97719        3.97719
  14.2197        14.2197
  -1.24031       -1.24031
  -7.41824       -7.41824
   1.90207        1.90207
   1.10939        1.10939
  -7.47202       -7.47202
   3.85738        3.85738
  -4.12085       -4.12085
   1.12097        1.12097
  -0.545646      -0.545646
   3.04129        3.04129
   1.05043        1.05043
   0.993448       0.993448
  -5.78424       -5.78424
  -1.97199       -1.97199
  -5.74806       -5.74806
   2.70835        2.70835
  -8.09729       -8.09729
  -6.36035       -6.36035
  -1.24361       -1.24361
  -2.44813       -2.44813
   7.48353        7.48353
   2.0202         2.0202
   3.04366        3.04366
  -3.98778       -3.98778
   4.80106        4.80106
   0.926552       0.926552
   3.35253        3.35253
  -4.10577       -4.10577
  -3.57853       -3.57853
   4.03372        4.03372
  -2.38792       -2.38792
   0.12177        0.12177
  -0.761671      -0.761671
  -4.25652       -4.25652
   7.27933        7.27933
   0.165182       0.165182
   1.34367        1.34367
  -7.36923       -7.36923
   2.38548        2.38548
   0.117217       0.117217
   2.02002        2.02002
  -4.60023       -4.60023
   2.78           2.78
  -1.34604       -1.34604
   4.7234         4.7234
   7.37673        7.37673
   2.07986        2.07986
  -5.72573       -5.72573
  -6.66143       -6.66143
   2.43072        2.43072
   1.34782        1.34782
  -0.114238      -0.114238
   2.32103        2.32103
   1.84042        1.84042
   1.07005        1.07005
   3.88182        3.88182
  -0.752264      -0.752264
  -2.43517       -2.43517
  -5.29216       -5.29216
  -0.13527       -0.13527
   1.40188        1.40188
  -5.87815       -5.87815
  -1.90167       -1.90167
   2.88562        2.88562
  -2.29028       -2.29028
   2.35477        2.35477
  -3.50731       -3.50731
   6.0621         6.0621
   3.2011         3.2011
   2.19115        2.19115
  -3.03557       -3.03557
  -8.49394       -8.49394
   0.936501       0.936501
   7.19188        7.19188
   4.50162        4.50162
   0.341394       0.341394
   2.54484        2.54484
   1.67305        1.67305
   3.05008        3.05008
  -2.0266        -2.0266
   7.28431        7.28431
  -7.70924       -7.70924
   2.60851        2.60851
   6.8054         6.8054
   1.8878         1.8878
   1.87624        1.87624
  -5.13611       -5.13611
  -3.23698       -3.23698
   4.03201        4.03201
  -5.27165       -5.27165
  -4.95817       -4.95817
  -0.200461      -0.200461
   4.27259        4.27259
   0.449661       0.449661
   7.49752        7.49752
  -5.47923       -5.47923
  -2.40934       -2.40934
  25.0066        25.0066
  -3.14511       -3.14511
  -1.62587       -1.62587
  -1.67652       -1.67652
  -2.17888       -2.17888
   2.37296        2.37296
  -4.41408       -4.41408
   0.65204        0.65204
  10.849         10.849
  -2.3021        -2.3021
   2.20417        2.20417
  10.0579        10.0579
  -4.03489       -4.03489
   7.60982        7.60982
  -5.74951       -5.74951
  -2.97582       -2.97582
  -8.61382       -8.61382
  -1.90903       -1.90903
  -3.64556       -3.64556
 -16.2304       -16.2304
 -15.9793       -15.9793
  -4.59448       -4.59448
  -2.67688       -2.67688
  -1.67148       -1.67148
   5.57026        5.57026
   0.846445       0.846445
  -7.54149       -7.54149
  -3.61401       -3.61401
   4.03723        4.03723
   0.711821       0.711821
   8.99009        8.99009
  -6.15866       -6.15866
  -1.36865       -1.36865
  -4.31058       -4.31058
   6.31659        6.31659
  -6.23773       -6.23773
   0.857388       0.857388
   3.6152         3.6152
  -1.28774       -1.28774
  -4.92094       -4.92094
   3.08527        3.08527
  -5.74582       -5.74582
  -4.20897       -4.20897
  -5.19406       -5.19406
  -4.06851       -4.06851
   5.73867        5.73867
   3.32767        3.32767
 -11.2588       -11.2588
  -7.94126       -7.94126
   5.38746        5.38746
  -0.0253579     -0.0253579
  -1.7856        -1.7856
  -1.31209       -1.31209
   6.85519        6.85519
   2.71496        2.71496
  -2.58838       -2.58838
  -6.86996       -6.86996
   1.01204        1.01204
   3.43433        3.43433
  -0.249192      -0.249192
   7.96322        7.96322
  14.3414        14.3414
   2.44774        2.44774
   4.73731        4.73731
  -9.14288       -9.14288
   2.70325        2.70325
   6.48202        6.48202
  -2.58391       -2.58391
  -4.52079       -4.52079
  -0.64105       -0.64105
  -3.75531       -3.75531
  -3.93321       -3.93321
  -2.5879        -2.5879
   2.34697        2.34697
  -3.89721       -3.89721
  -1.60712       -1.60712
  -7.49452       -7.49452
  -0.518596      -0.518596
   0.996693       0.996693
   2.83468        2.83468
  -6.19363       -6.19363
  -7.25683       -7.25683
   0.391546       0.391546
  -7.52756       -7.52756
  -0.810817      -0.810817
  -2.64942       -2.64942
  -2.95081       -2.95081
  -6.34989       -6.34989
   3.9961         3.9961
   1.36755        1.36755
  -0.335808      -0.335808
 -11.7919       -11.7919
   1.16904        1.16904
   6.26031        6.26031
  -4.68064       -4.68064
   5.55008        5.55008
   3.65873        3.65873
  -3.95177       -3.95177
   7.62708        7.62708
  -2.4932        -2.4932
  -0.713266      -0.713266
   6.76214        6.76214
  -0.802523      -0.802523
  -0.327543      -0.327543
  -6.9053        -6.9053
  -2.69604       -2.69604
   9.729          9.729
  -7.61691       -7.61691
  -0.658653      -0.658653
   1.62531        1.62531
   0.532107       0.532107
   1.71729        1.71729
 -10.1795       -10.1795
   5.54208        5.54208
   4.02502        4.02502
  -1.47596       -1.47596
  11.818         11.818
   4.40414        4.40414
   5.64827        5.64827
   5.89386        5.89386
  -6.19187       -6.19187
   4.77889        4.77889
  -0.261731      -0.261731
  -0.570525      -0.570525
   3.80941        3.80941
  -3.95414       -3.95414
   0.642971       0.642971
  -7.23493       -7.23493
   0.744423       0.744423
  11.5682        11.5682
  -3.17145       -3.17145
   9.02877        9.02877
  10.5452        10.5452
  -7.05642       -7.05642
  -6.01952       -6.01952
  -5.61355       -5.61355
   1.28759        1.28759
   3.44186        3.44186
  -2.52363       -2.52363
   8.95712        8.95712
  -1.33999       -1.33999
  -3.25858       -3.25858
   2.33509        2.33509
   2.16314        2.16314
  14.4002        14.4002
  -5.22345       -5.22345
  -5.6232        -5.6232
  -4.20801       -4.20801
   0.677359       0.677359
   1.92688        1.92688
   2.4265         2.4265
  -3.47901       -3.47901
  -3.35004       -3.35004
  -5.32445       -5.32445
   0.817822       0.817822
   5.9241         5.9241
   2.13342        2.13342
   9.30726        9.30726
  -6.00328       -6.00328
   5.10125        5.10125
  16.6941        16.6941
  -1.41774       -1.41774
   0.843709       0.843709
   3.71326        3.71326
 -12.7315       -12.7315
  -1.58947       -1.58947
   2.7713         2.7713
  -5.89993       -5.89993
 -10.1427       -10.1427
  -1.60823       -1.60823
  -4.98621       -4.98621
 -10.6258       -10.6258
   0.255858       0.255858
   5.87781        5.87781
   0.549239       0.549239
  -0.361649      -0.361649
   2.89543        2.89543
  -1.56252       -1.56252
  -7.04269       -7.04269
   0.360599       0.360599
  -0.80318       -0.80318
  -8.15537       -8.15537
   7.86106        7.86106
   4.25906        4.25906
   1.78474        1.78474
   4.15764        4.15764
  -1.8884        -1.8884
  -7.16959       -7.16959
   2.84539        2.84539
  -3.33161       -3.33161
   4.89863        4.89863
  -3.36503       -3.36503
  -4.68013       -4.68013
   5.18058        5.18058
  -9.69276       -9.69276
  -1.56116       -1.56116
  -3.58275       -3.58275
  -2.73766       -2.73766
   6.64492        6.64492
  -3.78966       -3.78966
   2.63467        2.63467
 -12.4868       -12.4868
  -3.4241        -3.4241
   3.2898         3.2898
   2.20265        2.20265
  -1.36672       -1.36672
   2.71448        2.71448
   5.87839        5.87839
   0.160837       0.160837
  -2.64458       -2.64458
  -3.8078        -3.8078
   5.08743        5.08743
 -14.014        -14.014
   4.44746        4.44746
   6.61584        6.61584
  -0.916513      -0.916513
  -8.08277       -8.08277
  -8.088         -8.088
  -5.14152       -5.14152
  -4.30739       -4.30739
  -8.76727       -8.76727
  -4.53313       -4.53313
  11.0356        11.0356
  -2.37348       -2.37348
  -8.71711       -8.71711
  -2.22971       -2.22971
   8.19346        8.19346
  -0.330962      -0.330962
   1.10067        1.10067
   1.01878        1.01878
 -10.2666       -10.2666
   8.15909        8.15909
   9.09316        9.09316
  -0.862864      -0.862864
  -7.54443       -7.54443
  -3.44703       -3.44703
   5.21819        5.21819
  -2.06834       -2.06834
   9.55442        9.55442
  -1.89649       -1.89649
  -5.57892       -5.57892
   4.22421        4.22421
  -4.06375       -4.06375
   3.81452        3.81452
   3.09071        3.09071
  -7.34297       -7.34297
  -1.67899       -1.67899
   0.58489        0.58489
  -5.33824       -5.33824
   2.82705        2.82705
  -3.70864       -3.70864
   4.21641        4.21641
   3.82508        3.82508
  -4.04356       -4.04356
  20.0249        20.0249
 -13.1531       -13.1531
   2.98603        2.98603
   5.54713        5.54713
  -1.39722       -1.39722
   2.13016        2.13016
  -2.40215       -2.40215
   0.168123       0.168123
   2.77021        2.77021
  -2.32327       -2.32327
  -1.06731       -1.06731
   2.53877        2.53877
  -1.94325       -1.94325
   1.47106        1.47106
   0.294436       0.294436
  -0.547055      -0.547055
   0.116016       0.116016
   1.56148        1.56148
   3.21789        3.21789
  -2.89007       -2.89007
  -4.33765       -4.33765
   0.566163       0.566163
   0.402729       0.402729
  -7.80674       -7.80674
   4.72058        4.72058
   3.97584        3.97584
   1.91646        1.91646
   2.09298        2.09298
   1.88552        1.88552
  -2.37581       -2.37581
 -18.2615       -18.2615
   2.68651        2.68651
   5.5            5.5
   0.355051       0.355051
   5.6052         5.6052
   7.74854        7.74854
  -0.512378      -0.512378
   1.60299        1.60299
  -5.49563       -5.49563
  -1.96455       -1.96455
 -16.3228       -16.3228
  -6.87737       -6.87737
  -4.60755       -4.60755
  -1.32116       -1.32116
   2.87263        2.87263
  -2.09541       -2.09541
   3.43595        3.43595
   3.63528        3.63528
   3.52056        3.52056
  -3.59484       -3.59484
   1.03764        1.03764
  -7.14947       -7.14947
  -5.80634       -5.80634
   4.71397        4.71397
   0.720588       0.720588
  -2.24074       -2.24074
   5.82418        5.82418
  -3.22013       -3.22013
   3.68858        3.68858
  -1.43166       -1.43166
   4.47978        4.47978
  -4.83356       -4.83356
  -3.96257       -3.96257
  -5.95512       -5.95512
   0.496691       0.496691
  -7.58825       -7.58825
  -6.47331       -6.47331
  -1.14446       -1.14446
   3.91615        3.91615
  -0.588841      -0.588841
   6.56683        6.56683
   3.97252        3.97252
  -4.3126        -4.3126
  -8.20913       -8.20913
   0.310182       0.310182
  -7.3006        -7.3006
   7.92805        7.92805
   2.1756         2.1756
   1.06404        1.06404
   1.14471        1.14471
  -1.50242       -1.50242
   0.00723557     0.00723557
   5.76841        5.76841
  -1.96707       -1.96707
   8.87243        8.87243
  -3.23281       -3.23281
  12.3087        12.3087
   3.3245         3.3245
   3.00334        3.00334
  -5.74048       -5.74048
   7.43939        7.43939
  -0.906001      -0.906001
   2.24067        2.24067
  -6.23989       -6.23989
   2.81483        2.81483
  -1.62648       -1.62648
  -7.26368       -7.26368
   1.69171        1.69171
 -11.2631       -11.2631
  -2.32992       -2.32992
  -6.07361       -6.07361
  -7.56822       -7.56822
  -7.56737       -7.56737
   5.97037        5.97037
   6.74398        6.74398
  -2.24599       -2.24599
   2.95213        2.95213
 -12.7864       -12.7864
   0.680035       0.680035
  -1.39988       -1.39988
  -4.74028       -4.74028
   3.01887        3.01887
   1.89636        1.89636
   4.46014        4.46014
  -4.38308       -4.38308
  11.7633        11.7633
  -3.54671       -3.54671
  -3.47584       -3.47584
   3.80037        3.80037
   7.77849        7.77849
  -7.00006       -7.00006
  -4.87665       -4.87665
  -4.54736       -4.54736
  -7.81752       -7.81752
  -0.0654465     -0.0654465
  -3.70587       -3.70587
  -2.24231       -2.24231
   5.58005        5.58005
  -3.09415       -3.09415
  -5.55063       -5.55063
  -4.19666       -4.19666
  -6.83328       -6.83328
  -6.9216        -6.9216
  -3.72782       -3.72782
  -2.18574       -2.18574
   1.28076        1.28076
  -3.40691       -3.40691
   0.486964       0.486964
  -2.11025       -2.11025
  -1.42349       -1.42349
   6.06854        6.06854
  -1.37534       -1.37534
   9.47832        9.47832
  -0.567045      -0.567045
  -6.98328       -6.98328
   6.73139        6.73139
  -1.56812       -1.56812
   0.141683       0.141683
   1.78697        1.78697
  -2.03874       -2.03874
   1.28356        1.28356
   6.9912         6.9912
  -3.8858        -3.8858
  -1.38808       -1.38808
  -2.16632       -2.16632
   3.57955        3.57955
   2.73506        2.73506
  -3.03108       -3.03108
  -3.44677       -3.44677
   1.37111        1.37111
 -10.0008       -10.0008
  -3.61651       -3.61651
   1.97313        1.97313
   2.11298        2.11298
   0.174957       0.174957
  -0.131546      -0.131546
   7.58484        7.58484
   4.27907        4.27907
   0.855439       0.855439
   4.44153        4.44153
  -1.04577       -1.04577
  -7.49625       -7.49625
   2.1572         2.1572
  13.0815        13.0815
   4.57025        4.57025
   0.704658       0.704658
   3.25079        3.25079
  -0.682139      -0.682139
  -4.17209       -4.17209
  -1.38547       -1.38547
   5.52688        5.52688
  -4.90717       -4.90717
   2.56402        2.56402
  -1.37164       -1.37164
  -6.05044       -6.05044
   8.3158         8.3158
  -0.640461      -0.640461
  -2.40145       -2.40145
  -1.02959       -1.02959
  -6.75028       -6.75028
   4.20206        4.20206
   0.615412       0.615412
  -0.389435      -0.389435
  -5.07439       -5.07439
  -5.34136       -5.34136
  -1.88522       -1.88522
  -4.82628       -4.82628
   0.54435        0.54435
  -3.28948       -3.28948
   5.0051         5.0051
  -8.5501        -8.5501
   7.31448        7.31448
   0.145651       0.145651
   3.28586        3.28586
  -1.8624        -1.8624
  -8.9235        -8.9235
   3.15894        3.15894
  -9.9459        -9.9459
   0.517233       0.517233
  -4.59899       -4.59899
   0.641116       0.641116
  10.3809        10.3809
   2.39935        2.39935
  -0.378496      -0.378496
   0.680329       0.680329
   2.35584        2.35584
  -2.24714       -2.24714
  -4.8742        -4.8742
  -3.96429       -3.96429
   1.29263        1.29263
   0.618875       0.618875
  -0.611961      -0.611961
   1.06612        1.06612
  -3.39289       -3.39289
  -0.226022      -0.226022
   4.24418        4.24418
   0.884239       0.884239
   8.25747        8.25747
  -3.23019       -3.23019
  -9.99374       -9.99374
   8.54414        8.54414
  -6.06374       -6.06374
  -4.92601       -4.92601
   7.22101        7.22101
  11.5756        11.5756
  13.436         13.436
   4.13522        4.13522
   9.67412        9.67412
  -3.13805       -3.13805
   7.50856        7.50856
  -7.98069       -7.98069
   4.92059        4.92059
  -6.72969       -6.72969
  -4.48762       -4.48762
  -3.60328       -3.60328
  -1.75053       -1.75053
   1.5638         1.5638
   4.74213        4.74213
   5.16046        5.16046
  -1.9857        -1.9857
  -6.34885       -6.34885
  -3.58963       -3.58963
   4.96795        4.96795
   1.44405        1.44405
  -2.74682       -2.74682
  -0.545296      -0.545296
 -10.7507       -10.7507
  -0.117477      -0.117477
  -0.436907      -0.436907
  -1.11656       -1.11656
   1.64789        1.64789
  -4.08799       -4.08799
  -1.04262       -1.04262
   6.06007        6.06007
  -6.68208       -6.68208
   6.81976        6.81976
  -6.89836       -6.89836
  -0.555115      -0.555115
  -2.85307       -2.85307
  -7.76567       -7.76567
  -5.65104       -5.65104
   8.93521        8.93521
  -5.0663        -5.0663
   2.52214        2.52214
   0.382824       0.382824
  -0.398468      -0.398468
   5.05183        5.05183
   4.134          4.134
   1.42909        1.42909
   2.99357        2.99357
  10.7821        10.7821
  -4.54764       -4.54764
  -0.0440308     -0.0440308
   0.647161       0.647161
   3.27569        3.27569
 -32.9478       -32.9478
   6.92399        6.92399
  -3.05953       -3.05953
  -2.29742       -2.29742
  -0.41863       -0.41863
   2.99125        2.99125
   3.40805        3.40805
  -1.36651       -1.36651
  -3.25561       -3.25561
   5.11504        5.11504
  -0.532291      -0.532291
   9.93341        9.93341
  -2.2806        -2.2806
  10.9617        10.9617
  -2.53642       -2.53642
   0.995763       0.995763
  -1.28898       -1.28898
  -2.99921       -2.99921
  -2.46773       -2.46773
 -11.0849       -11.0849
 -11.64         -11.64
  -3.73617       -3.73617
   2.74223        2.74223
  -0.976817      -0.976817
  -0.384814      -0.384814
  -3.38815       -3.38815
   2.27591        2.27591
  -5.25732       -5.25732
  -1.65764       -1.65764
  -5.8501        -5.8501
  -4.85863       -4.85863
   2.78987        2.78987
   5.3324         5.3324
  -9.16758       -9.16758
   7.90047        7.90047
   5.68696        5.68696
   7.2668         7.2668
  -0.857072      -0.857072
   0.0834347      0.0834347
   1.11833        1.11833
   0.88212        0.88212
  -4.40785       -4.40785
   5.25846        5.25846
   7.46283        7.46283
   6.26981        6.26981
 -10.8935       -10.8935
  -0.226332      -0.226332
  -1.64568       -1.64568
  -0.389003      -0.389003
  -0.854872      -0.854872
  -3.38063       -3.38063
  -4.74874       -4.74874
  -1.81717       -1.81717
  -6.03338       -6.03338
   9.41153        9.41153
  -2.75636       -2.75636
  -4.03638       -4.03638
  -2.82527       -2.82527
   0.641039       0.641039
  -3.08939       -3.08939
  -1.04523       -1.04523
  -4.17379       -4.17379
   0.453503       0.453503
   5.64541        5.64541
   2.72225        2.72225
  -1.67354       -1.67354
  -6.68729       -6.68729
  -1.20785       -1.20785
   3.51562        3.51562
   2.38257        2.38257
   2.75735        2.75735
  -4.62925       -4.62925
   7.98247        7.98247
   6.254          6.254
   3.85448        3.85448
  -4.40298       -4.40298
  -8.28751       -8.28751
  -7.28055       -7.28055
   7.31675        7.31675
   3.53957        3.53957
   2.94378        2.94378
   1.41268        1.41268
   5.2878         5.2878
  -0.807317      -0.807317
 -13.141        -13.141
   5.71505        5.71505
  -3.86739       -3.86739
   0.922435       0.922435
  -4.52167       -4.52167
   0.82741        0.82741
   4.1254         4.1254
  -3.64229       -3.64229
  -4.34879       -4.34879
  -5.69361       -5.69361
  10.0503        10.0503
  -6.20878       -6.20878
  -5.70531       -5.70531
  -0.265037      -0.265037
   4.91217        4.91217
  -9.85839       -9.85839
   9.14639        9.14639
   0.78426        0.78426
  -6.03581       -6.03581
  -1.225         -1.225
  -1.82514       -1.82514
  -4.38257       -4.38257
  -4.14898       -4.14898
   1.30056        1.30056
  -4.04361       -4.04361
 -10.7862       -10.7862
  -1.71033       -1.71033
  -5.3235        -5.3235
  -5.05158       -5.05158
   2.03088        2.03088
  -4.639         -4.639
  -8.90379       -8.90379
  -1.46286       -1.46286
   4.78737        4.78737
   2.84292        2.84292
  -4.60125       -4.60125
  -0.454598      -0.454598
  -3.54703       -3.54703
  -3.15574       -3.15574
  -5.66794       -5.66794
  -0.499733      -0.499733
   4.80394        4.80394
   7.0018         7.0018
 -12.2494       -12.2494
  -0.705371      -0.705371
   0.0740021      0.0740021
  -2.66987       -2.66987
   2.48263        2.48263
  -9.06332       -9.06332
  -1.01261       -1.01261
   3.84118        3.84118
   4.21216        4.21216
  -1.18673       -1.18673
 -11.0005       -11.0005
  -9.71638       -9.71638
   1.76212        1.76212
  -2.83766       -2.83766
  -9.13768       -9.13768
  -1.05015       -1.05015
   2.53008        2.53008
   0.379504       0.379504
   5.28803        5.28803
  -6.17221       -6.17221
   5.75619        5.75619
   2.3737         2.3737
  -9.0974        -9.0974
  -7.85433       -7.85433
 -10.9094       -10.9094
   1.20756        1.20756
   2.61486        2.61486
   1.23359        1.23359
  43.6151        43.6151
  -1.72859       -1.72859
  -0.965831      -0.965831
  -0.482239      -0.482239
  -1.82159       -1.82159
   1.661          1.661
   1.93636        1.93636
 -11.9999       -11.9999
   0.104367       0.104367
  -1.70555       -1.70555
  -9.81074       -9.81074
  12.7941        12.7941
  -3.36221       -3.36221
  -6.06523       -6.06523
   0.47411        0.47411
  -6.64475       -6.64475
  -0.763006      -0.763006
  -3.9763        -3.9763
  -2.86732       -2.86732
 -20.6937       -20.6937
   1.84418        1.84418
   5.65243        5.65243
  10.7255        10.7255
  -1.21293       -1.21293
   3.15057        3.15057
   8.96094        8.96094
  -0.205015      -0.205015
   8.44579        8.44579
   2.01362        2.01362
   2.36648        2.36648
  11.6752        11.6752
   2.19072        2.19072
 -13.9182       -13.9182
   3.3257         3.3257
  -6.60627       -6.60627
   1.62083        1.62083
  -2.00847       -2.00847
  11.6978        11.6978
   5.93254        5.93254
   4.93134        4.93134
  -2.50847       -2.50847
  -5.92846       -5.92846
   1.16717        1.16717
   6.9673         6.9673
  -1.21182       -1.21182
   7.25413        7.25413
  -4.24031       -4.24031
  -3.12368       -3.12368
   1.73734        1.73734
  -2.6551        -2.6551
   5.01063        5.01063
  10.9923        10.9923
   3.08502        3.08502
  -1.67866       -1.67866
  10.7003        10.7003
  -0.982895      -0.982895
   1.97681        1.97681
  -1.29045       -1.29045
   1.64227        1.64227
   3.21157        3.21157
  -4.63376       -4.63376
   4.47725        4.47725
   7.77208        7.77208
   0.332548       0.332548
   2.82084        2.82084
   0.958649       0.958649
   1.21302        1.21302
  -3.16936       -3.16936
   0.0672417      0.0672417
   0.563038       0.563038
  -1.87542       -1.87542
  -3.01753       -3.01753
   2.73107        2.73107
  -3.68276       -3.68276
   4.64376        4.64376
 -12.4341       -12.4341
   4.43429        4.43429
   5.72878        5.72878
   2.39332        2.39332
   1.91106        1.91106
   2.50458        2.50458
   0.942479       0.942479
  -0.489758      -0.489758
   0.311101       0.311101
  -2.74953       -2.74953
   4.95959        4.95959
   1.26862        1.26862
  10.3622        10.3622
   3.61213        3.61213
  -2.19285       -2.19285
   1.28587        1.28587
  -1.85274       -1.85274
  -1.62541       -1.62541
   2.00382        2.00382
  -5.8959        -5.8959
  -0.918042      -0.918042
   6.43711        6.43711
   0.419441       0.419441
  -2.61133       -2.61133
  -0.0277654     -0.0277654
   2.77443        2.77443
   3.83764        3.83764
  -1.44486       -1.44486
  -0.611288      -0.611288
  -4.30436       -4.30436
   5.29466        5.29466
   1.56058        1.56058
   1.88962        1.88962
   0.761408       0.761408
   1.76505        1.76505
   1.18453        1.18453
   1.71559        1.71559
  -3.14851       -3.14851
   2.73145        2.73145
  -1.23904       -1.23904
   0.00672958     0.00672958
   3.40979        3.40979
  -1.77498       -1.77498
  -7.12266       -7.12266
  -9.24697       -9.24697
  -4.12038       -4.12038
  -2.77817       -2.77817
   8.23453        8.23453
  -1.29818       -1.29818
  -7.02203       -7.02203
  -5.8994        -5.8994
   8.20499        8.20499
   0.356509       0.356509
  -0.515947      -0.515947
  -6.23904       -6.23904
   5.59801        5.59801
  -4.44281       -4.44281
  -2.28591       -2.28591
  -3.31819       -3.31819
   2.39253        2.39253
   3.18355        3.18355
  -2.73303       -2.73303
  -0.0346074     -0.0346074
 -10.2692       -10.2692
   6.74308        6.74308
   5.72055        5.72055
  -4.49033       -4.49033
   1.99176        1.99176
   6.10782        6.10782
   2.65759        2.65759
   1.97884        1.97884
   0.927606       0.927606
   1.25006        1.25006
   9.3695         9.3695
  -2.75726       -2.75726
  -0.580415      -0.580415
   2.92463        2.92463
  -4.49535       -4.49535
  -1.61397       -1.61397
   3.26733        3.26733
  -3.61505       -3.61505
  -2.46453       -2.46453
   2.42436        2.42436
   5.68683        5.68683
   6.07494        6.07494
   4.35205        4.35205
  -5.29467       -5.29467
  -3.90039       -3.90039
  -1.70776       -1.70776
  -6.3172        -6.3172
   4.03858        4.03858
  -2.58786       -2.58786
  -1.1514        -1.1514
  -0.632569      -0.632569
  -0.343314      -0.343314
 -12.2115       -12.2115
   0.405742       0.405742
  -6.46017       -6.46017
  -2.30808       -2.30808
   1.1336         1.1336
   1.47556        1.47556
   1.98494        1.98494
   2.24865        2.24865
  -1.65786       -1.65786
  -4.62769       -4.62769
   4.43717        4.43717
   8.75249        8.75249
   4.29167        4.29167
  -3.96876       -3.96876
  -3.52244       -3.52244
   0.161164       0.161164
  -4.13202       -4.13202
   1.42269        1.42269
  -3.05155       -3.05155
   1.81371        1.81371
  -1.03765       -1.03765
   0.696656       0.696656
   2.95359        2.95359
  -4.74837       -4.74837
  -9.03481       -9.03481
   4.8852         4.8852
   9.47173        9.47173
  11.3037        11.3037
  -3.88084       -3.88084
  -5.99356       -5.99356
   7.81639        7.81639
  -6.51949       -6.51949
   7.801          7.801
  -0.795429      -0.795429
  -0.801046      -0.801046
   2.70658        2.70658
   5.51012        5.51012
   1.8181         1.8181
  -0.452854      -0.452854
 -10.1558       -10.1558
   1.95877        1.95877
  -3.88197       -3.88197
   1.72033        1.72033
  -1.8939        -1.8939
  -1.64082       -1.64082
  -0.409815      -0.409815
   9.98658        9.98658
  -0.115277      -0.115277
   1.49827        1.49827
   1.6696         1.6696
   2.29297        2.29297
  -2.14941       -2.14941
   2.43318        2.43318
   3.59845        3.59845
  -4.58877       -4.58877
  -9.25371       -9.25371
   2.03609        2.03609
   5.5921         5.5921
  -0.532859      -0.532859
   4.34937        4.34937
   1.57036        1.57036
   2.30747        2.30747
   7.5055         7.5055
   3.41771        3.41771
   0.589402       0.589402
   1.55834        1.55834
   5.12407        5.12407
  -1.41727       -1.41727
   1.03223        1.03223
  -2.06257       -2.06257
   3.11532        3.11532
   1.90042        1.90042
   8.66814        8.66814
   5.36716        5.36716
   2.38085        2.38085
   5.72834        5.72834
  -6.5998        -6.5998
   0.852569       0.852569
  -7.5648        -7.5648
   2.98063        2.98063
   7.81573        7.81573
   1.82276        1.82276
  -1.81083       -1.81083
   5.48043        5.48043
  -1.85315       -1.85315
  -1.62277       -1.62277
 -10.4951       -10.4951
   5.34799        5.34799
  -1.77515       -1.77515
   5.88005        5.88005
   0.0799242      0.0799242
   1.23264        1.23264
 -11.835        -11.835
   3.56828        3.56828
   7.53741        7.53741
  -5.24051       -5.24051
  -0.206917      -0.206917
   4.36865        4.36865
  -4.10348       -4.10348
   0.857712       0.857712
  -5.09677       -5.09677
   7.37208        7.37208
  -3.14614       -3.14614
  12.061         12.061
   4.80096        4.80096
   2.82421        2.82421
  -4.97446       -4.97446
 -11.0289       -11.0289
  -8.33282       -8.33282
   0.69922        0.69922
   5.08771        5.08771
   2.65174        2.65174
  -3.30182       -3.30182
   5.21741        5.21741
   8.85373        8.85373
   8.36416        8.36416
   2.54295        2.54295
  -1.61657       -1.61657
   1.12017        1.12017
  -7.33205       -7.33205
   3.82582        3.82582
  -0.858026      -0.858026
   1.40304        1.40304
   1.35079        1.35079
   4.19532        4.19532
  -1.77923       -1.77923
 -10.5119       -10.5119
  10.8061        10.8061
  -3.49603       -3.49603
   3.12404        3.12404
  -3.93328       -3.93328
  -6.73356       -6.73356
   1.80532        1.80532
  -0.368024      -0.368024
  -3.47875       -3.47875
  -4.22893       -4.22893
   2.52519        2.52519
  -3.54943       -3.54943
  -2.39869       -2.39869
   4.22126        4.22126
  -0.253856      -0.253856
   7.51866        7.51866
  -4.54093       -4.54093
   3.44497        3.44497
   4.77417        4.77417
   4.49646        4.49646
  -5.78678       -5.78678
   0.745013       0.745013
   1.69763        1.69763
  -2.64759       -2.64759
   1.66108        1.66108
  -4.68276       -4.68276
   5.31823        5.31823
   3.52288        3.52288
   4.9695         4.9695
  12.2016        12.2016
   2.46849        2.46849
  -7.60038       -7.60038
   8.21628        8.21628
   5.99856        5.99856
  -6.80947       -6.80947
   7.22522        7.22522
  -2.00065       -2.00065
  -8.24049       -8.24049
  -0.0804049     -0.0804049
  -2.06638       -2.06638
  -2.82884       -2.82884
  -4.25891       -4.25891
  -5.20258       -5.20258
  -3.19396       -3.19396
  -5.14527       -5.14527
  -4.28244       -4.28244
   4.70805        4.70805
  -3.08065       -3.08065
  -4.86906       -4.86906
 -29.0266       -29.0266
  -1.22941       -1.22941
  -1.30928       -1.30928
  -6.35234       -6.35234
   1.87904        1.87904
   8.37797        8.37797
  -5.8821        -5.8821
   3.10138        3.10138
  -3.27553       -3.27553
  -0.208451      -0.208451
  -2.28999       -2.28999
  12.2896        12.2896
  -1.27394       -1.27394
  -3.41924       -3.41924
  -0.289592      -0.289592
   1.79867        1.79867
   1.98504        1.98504
   1.55159        1.55159
   1.10858        1.10858
   0.352842       0.352842
  -0.309044      -0.309044
  -0.165336      -0.165336
   1.15822        1.15822
  -1.39342       -1.39342
  -0.162562      -0.162562
  -8.06055       -8.06055
  -5.02776       -5.02776
  -8.66927       -8.66927
   1.14576        1.14576
  -1.52122       -1.52122
  -1.29436       -1.29436
   3.26421        3.26421
   7.55561        7.55561
   7.7265         7.7265
  -0.48821       -0.48821
  12.439         12.439
   7.0264         7.0264
 -11.9855       -11.9855
  -3.74151       -3.74151
  -0.200302      -0.200302
   5.39515        5.39515
  -4.3468        -4.3468
   9.25599        9.25599
   3.37455        3.37455
  -6.15424       -6.15424
  -6.6271        -6.6271
   0.000272481    0.000272481
  -5.48117       -5.48117
  -0.493191      -0.493191
  -3.46473       -3.46473
   2.33812        2.33812
   0.885965       0.885965
   4.74926        4.74926
   1.51959        1.51959
   2.50956        2.50956
  -0.728024      -0.728024
   1.0381         1.0381
   5.48121        5.48121
  -1.68033       -1.68033
  -5.05915       -5.05915
  -0.646233      -0.646233
   0.614062       0.614062
   4.54219        4.54219
  -1.63006       -1.63006
  -3.10589       -3.10589
  -3.12801       -3.12801
  -5.98177       -5.98177
  -3.59188       -3.59188
   1.7066         1.7066
  -7.43935       -7.43935
  10.6141        10.6141
  12.6478        12.6478
  -1.7222        -1.7222
  -2.1519        -2.1519
  -7.16573       -7.16573
   0.887314       0.887314
  -8.59735       -8.59735
  -1.3609        -1.3609
   4.47651        4.47651
   0.900892       0.900892
   7.81857        7.81857
   6.19857        6.19857
   2.12844        2.12844
   3.08551        3.08551
   4.15866        4.15866
   2.09657        2.09657
  -2.27786       -2.27786
   1.33571        1.33571
   4.46899        4.46899
   4.46674        4.46674
   3.20736        3.20736
   5.68287        5.68287
  10.1058        10.1058
   5.1894         5.1894
   3.5452         3.5452
  10.06          10.06
   7.02935        7.02935
  -1.06066       -1.06066
  10.32          10.32
  -0.860463      -0.860463
   5.95992        5.95992
  -6.30137       -6.30137
  -5.01947       -5.01947
   5.75187        5.75187
  -1.10079       -1.10079
  -1.91783       -1.91783
   0.815744       0.815744
  -0.958663      -0.958663
  -3.28825       -3.28825
  -6.37854       -6.37854
   6.91577        6.91577
   2.54565        2.54565
   1.39487        1.39487
   1.59679        1.59679
   4.72347        4.72347
   2.49221        2.49221
   1.29896        1.29896
  -4.08232       -4.08232
  -0.648436      -0.648436
  -6.43531       -6.43531
  -0.556197      -0.556197
  -1.40304       -1.40304
   0.699818       0.699818
  -5.29777       -5.29777
  -3.44335       -3.44335
   7.35309        7.35309
   8.846          8.846
   8.39833        8.39833
  -2.71436       -2.71436
   3.37063        3.37063
  -3.18723       -3.18723
   1.32256        1.32256
  -3.09485       -3.09485
   8.78146        8.78146
  -1.30004       -1.30004
   3.03526        3.03526
  -1.4592        -1.4592
   3.90288        3.90288
 -13.5124       -13.5124
   1.35105        1.35105
   3.37337        3.37337
   2.5171         2.5171
  -4.22085       -4.22085
  13.1858        13.1858
  -6.02839       -6.02839
   5.75692        5.75692
   2.46171        2.46171
  -0.950315      -0.950315
  -3.63255       -3.63255
   1.88           1.88
   5.48758        5.48758
   4.96786        4.96786
  -6.17199       -6.17199
  -0.284244      -0.284244
  -1.80256       -1.80256
   3.03221        3.03221
  -8.90171       -8.90171
  -8.66084       -8.66084
  -9.06366       -9.06366
  -3.02007       -3.02007
  -8.2276        -8.2276
   8.10032        8.10032
  -4.11364       -4.11364
  -3.39291       -3.39291
   3.64208        3.64208
  -0.739833      -0.739833
  -2.84156       -2.84156
  -0.843081      -0.843081
  -0.249744      -0.249744
   7.05075        7.05075
   0.369632       0.369632
  -1.90893       -1.90893
   9.79465        9.79465
   3.52356        3.52356
   4.14091        4.14091
   1.66568        1.66568
 -10.7162       -10.7162
  -7.64522       -7.64522
   1.54688        1.54688
   7.84479        7.84479
   0.466458       0.466458
   4.03315        4.03315
   0.472926       0.472926
   1.73319        1.73319
   1.79317        1.79317
   1.46234        1.46234
  -8.45267       -8.45267
   7.30327        7.30327
   3.08869        3.08869
   5.27442        5.27442
   2.92876        2.92876
  -1.6673        -1.6673
  14.4442        14.4442
  13.4055        13.4055
  -1.47522       -1.47522
  -3.57821       -3.57821
   9.00659        9.00659
  -9.6723        -9.6723
   2.8818         2.8818
  -2.61898       -2.61898
   1.17927        1.17927
  -3.15135       -3.15135
  -0.976968      -0.976968
   1.45062        1.45062
   4.66687        4.66687
   4.94346        4.94346
  -2.20375       -2.20375
   2.93643        2.93643
   7.51365        7.51365
   6.50034        6.50034
   1.74088        1.74088
  -4.43403       -4.43403
   0.796894       0.796894
  -1.23803       -1.23803
   5.33941        5.33941
   4.90517        4.90517
   0.569053       0.569053
  -0.609673      -0.609673
   5.091          5.091
   1.76184        1.76184
  -3.81174       -3.81174
  -5.39095       -5.39095
  -3.09718       -3.09718
  -1.87868       -1.87868
  -4.85278       -4.85278
  -1.05327       -1.05327
  -1.11892       -1.11892
  -3.52006       -3.52006
  -2.8466        -2.8466
   3.03494        3.03494
   3.7605         3.7605
  -1.8123        -1.8123
  -5.10186       -5.10186
   2.85973        2.85973
  -3.6241        -3.6241
   1.78302        1.78302
 -12.3108       -12.3108
   0.378043       0.378043
  -1.70182       -1.70182
  -0.91773       -0.91773
  -5.37355       -5.37355
````

### Using postprocessing function
Add normalization as postprocessing function to normalize embeddings on reception (for easy cosine similarity later)

````julia
using LinearAlgebra
schema = PT.OllamaManagedSchema()

msg = aiembed(schema,
    ["embed me", "and me too"],
    LinearAlgebra.normalize;
    model = "openhermes2.5-mistral")
````

````
DataMessage(Matrix{Float64} of size (4096, 2))
````

Cosine similarity is then a simple multiplication

````julia
msg.content' * msg.content[:, 1]
````

````
2-element Vector{Float64}:
 0.9999999999999946
 0.34130017815042357
````

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

